@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -80,10 +80,15 @@ $id_sessione = "";
 $numero_contratto = aggslashdb((int) $doc);
 $api_esistente = esegui_query("select * from $tablecontratti where numero = '$numero_contratto' and tipo = 'api'");
 if (numlin_query($api_esistente)) {
-$max_log_sbagliati = 10;
-$minuti_durata_sessione = 30;
+$pass_api = risul_query($api_esistente,0,'testo');
+$id_utente = explode(";",$pass_api);
+$indirizzi_ip_api = $id_utente[1];
+$id_utente = $id_utente[0];
 if ($_SERVER['REMOTE_ADDR']) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
 $REMOTE_ADDR = aggslashdb($REMOTE_ADDR);
+if (!$indirizzi_ip_api or strstr(",$indirizzi_ip_api,",",$REMOTE_ADDR,")) {
+$max_log_sbagliati = 10;
+$minuti_durata_sessione = 30;
 $limite_transazioni_vecchie = date("Y-m-d H:i:s",(time() - ($minuti_durata_sessione * 60) + (C_DIFF_ORE * 3600)));
 esegui_query("delete from $tabletransazioniweb where tipo_transazione = 'api_l' and ultimo_accesso <= '$limite_transazioni_vecchie'");
 $login_sbagliati = esegui_query("select tipo_transazione from $tabletransazioniweb where tipo_transazione = 'api_l' and dati_transazione1 = 'doc$numero_contratto' and dati_transazione2 = '$REMOTE_ADDR' ");
@@ -92,10 +97,7 @@ if ($login_sbagliati >= $max_log_sbagliati) echo "Excessive number of failed log
 else {
 
 if (@get_magic_quotes_gpc()) $pass = stripslashes($pass);
-$pass_api = risul_query($api_esistente,0,'testo');
-$id_utente = explode(";",$pass_api);
-$id_utente = $id_utente[0];
-$pass_api = substr($pass_api,(strlen($id_utente) + 1));
+$pass_api = substr($pass_api,(strlen($id_utente) + strlen($indirizzi_ip_api) + 2));
 if ($pass == $pass_api) {
 
 $raggiunto_limite = 0;
@@ -255,9 +257,48 @@ $num_campi_pers_cliente = count($campi_pers_cliente);
 else $num_campi_pers_cliente = 0;
 include_once("./includes/funzioni_tariffe.php");
 $dati_cat_pers = dati_cat_pers($id_utente,$tablepersonalizza,$lingua_mex,"v",0,1);
+$dati_allegato = array('num' => 0);
+/*# PER ORA IL FORMATO EMAIL NON PUÒ ESSERE API (poi sostituire con nuova funzione dati_allegato($num_contr), da sostituire anche in visualizza_contratto, in funzioni_contratti?)
+$allegati_email = esegui_query("select * from $tablecontratti where numero = '$numero_contratto' and tipo = 'allegato'");
+if (numlin_query($allegati_email)) {
+$allegati_email = risul_query($allegati_email,0,'testo');
+if ($allegati_email) {
+if (strstr($allegati_email,":")) $contr_multilingua = 1;
+else $contr_multilingua = 0;
+$allegati_email = explode(",",$allegati_email);
+$dati_allegato['num'] = (count($allegati_email) - 2);
+for ($num1 = 1 ; $num1 <= $dati_allegato['num'] ; $num1++) {
+$dati_allegato['ln_corr'][$num1] = "SI";
+if ($contr_multilingua) {
+$all_vett = explode(">",$allegati_email[$num1]);
+$num_ln = count($all_vett);
+} # fine if ($contr_multilingua)
+else $num_ln = 1;
+for ($num2 = 0 ; $num2 < $num_ln ; $num2++) {
+if ($contr_multilingua) {
+$num_all = substr(strstr($all_vett[$num2],":"),1);
+$ln_corr = substr(str_replace(":$num_all","",$all_vett[$num2]),4);
+} # fine if ($contr_multilingua)
+else $num_all = $allegati_email[$num1];
+$allegato_email = esegui_query("select * from $tablecontratti where numero = '$num_all' and tipo = 'file_all'");
+$allegato_email = risul_query($allegato_email,0,'testo');
+$allegato_email = explode(",",$allegato_email);
+if ($contr_multilingua) $dati_allegato["ln$ln_corr"][$num1] = $allegato_email[0];
+else $dati_allegato['corr'][$num1] = $allegato_email[0];
+} # fine for $num2
+} # fine for $num1
+unset($ln_corr);
+unset($num_all);
+unset($all_vett);
+unset($num_ln);
+unset($allegato_email);
+} # fine if ($allegati_email)
+} # fine if (numlin_query($allegati_email))
+unset($allegati_email);*/
 $commento_personalizzato_ = "commento_personalizzato_";
 $campo_personalizzato_ = "campo_personalizzato_";
 $num_persone_tipo_ = "num_persone_tipo_";
+$allegato_ = "allegato";
 include("./includes/variabili_contratto.php");
 
 $tableprenota = $PHPR_TAB_PRE."prenota".$anno;
@@ -337,10 +378,10 @@ $query_prenota .= ",$num2";
 } # fine if (!$res_ini or !$res_fine or $res_fine >= $res_ini)
 } # fine if (str_replace("-","",$num_pren) != $num_pren)
 else {
-if (preg_match("/[0-9]*/",$num_pren) and !$prenota_in_lista[$num_pren]) {
+if (preg_match("/[0-9]*/",$num_pren) and empty($prenota_in_lista[$num_pren])) {
 $prenota_in_lista[$num_pren] = 1;
 $query_prenota .= ",$num_pren";
-} # fine if (preg_match("/[0-9]*/",$num_pren) and !$prenota_in_lista[$num_pren])
+} # fine if (preg_match("/[0-9]*/",$num_pren) and empty($prenota_in_lista[$num_pren]))
 } # fine else if (str_replace("-","",$num_pren) != $num_pren)
 } # fine for $num1
 if ($query_prenota) $lista_prenota = 1;
@@ -463,6 +504,8 @@ $mostra_headers = "SI";
 $messaggio_di_errore = "";
 $num_contr_esist = 0;
 $contratto = crea_contratto($numero_contratto,$tipo_contratto,"1","","","");
+if (!empty($nome_file_contr['downl']['num'])) $n_file = $nome_file_contr['downl']['num'];
+else $n_file = 1;
 
 if ($messaggio_di_errore) {
 $tipo_contratto = "contrhtm";
@@ -477,6 +520,8 @@ $messaggio_di_errore
 if ($dir_salva and !$num_contr_esist) $mostra_headers = "NO";
 $foothtm = "";
 
+if (!empty($nome_file_contr['downl']['datdownl'])) $dati_download = explode(">",$nome_file_contr['downl']['datdownl']);
+else $dati_download = "";
 if ($tipo_contratto == "contrhtm") {
 $show_bar = "NO";
 $headhtm = esegui_query("select testo from $tablecontratti where numero = '$numero_contratto' and tipo = 'headhtm'");
@@ -489,9 +534,10 @@ if (numlin_query($foothtm)) $foothtm = risul_query($foothtm,0,'testo');
 } # fine if ($tipo_contratto == "contrhtm")
 if ($tipo_contratto == "contrrtf") {
 $mostra_headers = "NO";
-if ($nome_file_contr) $nome_file = $nome_file_contr[$n_file];
-else $nome_file = str_replace("\\","_",str_replace("/","_",str_replace(" ","_",$nome_contratto))).".rtf";
+if (isset($nome_file_contr[$n_file])) $nome_file = $nome_file_contr[$n_file];
+else $nome_file = str_replace("\"","_",str_replace("\\","_",str_replace("/","_",str_replace(" ","_",$nome_contratto)))).".rtf";
 if (substr($nome_file,-3) == ".gz") $nome_file = substr($nome_file,0,-3);
+if (isset($dati_download[1]) and $dati_download[1] == "var" and isset($nome_file_contr['downl'][$n_file]) and strcmp($nome_file_contr['downl'][$n_file],"")) $nome_file = $nome_file_contr['downl'][$n_file].substr($nome_file,-4);
 header("Pragma: public");
 header("Last-Modified: ".gmdate("D, d M Y H:i:s")." GMT");
 header("Cache-Control: no-store, no-cache, must-revalidate");
@@ -505,16 +551,15 @@ header("Content-Disposition: inline; filename=\"$nome_file\"");
 } # fine if ($tipo_contratto == "contrrtf")
 if ($tipo_contratto == "contrtxt") {
 $mostra_headers = "NO";
-if ($nome_file_contr) {
+if (isset($nome_file_contr[$n_file])) {
 $nome_file = $nome_file_contr[$n_file];
 if (substr($nome_file,-3) == ".gz") $nome_file = substr($nome_file,0,-3);
-} # fine if ($nome_file_contr)
-else $nome_file = str_replace("\\","_",str_replace("/","_",str_replace(" ","_",$nome_contratto))).".txt";
-$est_txt = esegui_query("select * from $tablecontratti where numero = '$numero_contratto' and tipo = 'est_txt'");
-if (numlin_query($est_txt)) {
-$est_txt = risul_query($est_txt,0,'testo');
-$nome_file = substr($nome_file,0,-4).".$est_txt";
-} # fine if (numlin_query($est_txt))
+} # fine if (isset($nome_file_contr[$n_file]))
+else $nome_file = str_replace("\"","_",str_replace("\\","_",str_replace("/","_",str_replace(" ","_",$nome_contratto)))).".txt";
+if ($dati_download) {
+if (isset($dati_download[1]) and $dati_download[1] == "var" and isset($nome_file_contr['downl'][$n_file]) and strcmp($nome_file_contr['downl'][$n_file],"")) $nome_file = $nome_file_contr['downl'][$n_file].substr($nome_file,-4);
+if ($dati_download[0]) $nome_file = substr($nome_file,0,-4).".".$dati_download[0];
+} # fine if ($dati_download)
 header("Pragma: public");
 header("Last-Modified: ".gmdate("D, d M Y H:i:s")." GMT");
 header("Cache-Control: no-store, no-cache, must-revalidate");
@@ -554,6 +599,8 @@ esegui_query("insert into $tabletransazioniweb (idtransazioni,tipo_transazione,d
 } # fine else if ($pass == $pass_api)
 
 } # fine else if ($login_sbagliati >= $max_log_sbagliati)
+} # fine if (!$indirizzi_ip_api or strstr(",$indirizzi_ip_api,",",$REMOTE_ADDR,"))
+else echo "$REMOTE_ADDR not allowed.";
 } # fine if (numlin_query($api_esistente))
 } # fine if (!empty($doc))
 
@@ -646,12 +693,12 @@ if ($sessione_trovata) {
 @include(C_DATI_PATH."/tema.php");
 if (defined('C_UTENTE_CANC_CC') and $id_sessione == C_UTENTE_CANC_CC) $id_utente = 1;
 else {
-if (!empty($tweb)) {
-$id_utente = "t";
+if (!empty($tweb)) $id_utente = "t";
+else $id_utente = risul_query($sessione,0,'idutente');
+if ($id_utente == -1 or $id_utente == "t") {
 $lingua[$id_utente] = $lingua[1];
 $tema[$id_utente] = $tema[1];
-} # fine if (!empty($tweb))
-else $id_utente = risul_query($sessione,0,'idutente');
+} # fine if ($id_utente == -1 or $id_utente == "t")
 } # fine else if (defined('C_UTENTE_CANC_CC') and $id_sessione == C_UTENTE_CANC_CC)
 echo "<user_id>$id_utente<user_id>
 <lang>".$lingua[$id_utente]."</lang>
@@ -853,6 +900,7 @@ if (stristr($valore_xml,"<id>$token_res_id<")) {
 $lingua_mex = $lingua[1];
 $id_utente_sessione = "-1";
 $id_sessione = crea_id_sessione($anno,$tableversioni);
+if (C_VERSIONE_ATTUALE < 3.04) $id_sessione = substr($id_sessione,0,20).substr($id_sessione,30);
 $ultimo_accesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 if ($_SERVER['REMOTE_ADDR']) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
 $REMOTE_ADDR = aggslashdb($REMOTE_ADDR);
