@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -446,7 +446,7 @@ $file_tmp = C_DATI_PATH."/hoteld_doc_backup.php.tmp";
 $file_backup = C_DATI_PATH."/hoteld_doc_backup.php";
 } # fine else if (!isset($backup_contratti) or $backup_contratti != "SI")
 if (empty($file_backup_upload)) {
-fix_set($file_backup_upload);
+$file_backup_upload = fixstr($file_backup_upload);
 if (!empty($HTTP_POST_FILES['file_backup_upload']['tmp_name'])) $file_backup_upload = $HTTP_POST_FILES['file_backup_upload']['tmp_name'];
 else if (!empty($_FILES['file_backup_upload']['tmp_name'])) $file_backup_upload = $_FILES['file_backup_upload']['tmp_name'];
 } # fine if (empty($file_backup_upload))
@@ -843,7 +843,7 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"./crea_backup.php\
 <button class=\"rdbk\" type=\"submit\" name=\"ripristina_backup\" value=\"1\"><div>".mex("Ripristina i documenti dal file",$pag)."</div></button><br>
 <table><tr><td style=\"width: 30px;\"></td><td>
 <label><input type=\"radio\" name=\"modalita\" value=\"aggiungi\" checked>".mex("aggiungi ai documenti attuali",$pag)."</label>";
-if ($info_contr['max_contr'] > 1) {
+if (fixset($info_contr['max_contr']) > 1) {
 echo " <select name=\"contr_agg\">
 <option value=\"\" selected>".mex("tutti i documenti contenuti nel file",$pag)."</option>";
 unset($nomi_contratti);
@@ -859,7 +859,7 @@ if (isset($nomi_contratti[$num1]) and strcmp((string) $nomi_contratti[$num1],"")
 echo "</option>";
 } # fine for $num1
 echo "</select>";
-} # fine if ($info_contr['max_contr'] > 1)
+} # fine if (fixset($info_contr['max_contr'] > 1))
 echo "<br><label><input type=\"radio\" name=\"modalita\" value=\"rimpiazza\">".mex("rimpiazza i documenti attuali",$pag)."</label> (".mex("i documenti attuali verranno cancellati",$pag).")<br>";
 echo "</td></tr></table></div></form><table><tr><td style=\"height: 1px;\"></td></tr></table>";
 } # fine if ($file_esistente == "SI")
