@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -43,7 +43,12 @@ $var_pag[15] = 'regola_1_tar';
 $var_pag[16] = 'tipotariffa_regola3';
 $var_pag[17] = 'num_persone';
 $var_pag[18] = 'regola_3';
-$n_var_pag = 19;
+$var_pag[19] = 'regola_3m';
+$var_pag[20] = 'nor3m';
+$var_pag[21] = 'nor3';
+$var_pag[22] = 'id_utente_inserimento';
+$var_pag[23] = 'regola_4';
+$n_var_pag = 24;
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -731,7 +736,7 @@ $aggiorna_ic_disp = 1;
 } # fine if ((!empty($regola_2) or !empty($regola_2b)) and $priv_mod_reg2 == "s")
 
 
-if (!empty($regola_3) and $priv_mod_reg2 == "s") {
+if ((!empty($regola_3) or !empty($regola_3m)) and $priv_mod_reg2 == "s") {
 if (substr($tipotariffa,0,7) != "tariffa" or controlla_num_pos(substr($tipotariffa,7)) == "NO" or ($attiva_tariffe_consentite != "n" and !isset($tariffe_consentite_vett[substr($tipotariffa,7)]))) {
 $inserire = "NO";
 echo mex("Si deve scegliere la tariffa",$pag).".<br>";
@@ -745,11 +750,25 @@ $inserire = "NO";
 echo mex("La tariffa scelta ha già un numero di persone associato, cancella la regola prima di inserirne una nuova",$pag).".<br>";
 } # fine if ($num_regole_esistente != 0)
 */
-} # fine else if (substr($tipotariffa,0,7) != "tariffa" or...
-if (!$num_persone or controlla_num_pos($num_persone) != "SI") {
+if (controlla_num_pos($num_persone) != "SI" or (!$num_persone and !$num_regole_esistente)) {
 $inserire = "NO";
 echo mex("Si deve inserire il numero di persone da associare",$pag).".<br>";
-} # fine if (!$num_persone or controlla_num_pos($num_persone) != "SI")
+} # fine if (controlla_num_pos($num_persone) != "SI" or...
+} # fine else if (substr($tipotariffa,0,7) != "tariffa" or...
+if ((!isset($inserire) or $inserire != "NO") and $num_regole_esistente) {
+if (!empty($regola_3m)) {
+$pers_min = $num_persone;
+$pers_def = (string) risul_query($regola_esistente,0,'iddatainizio');
+} # fine if (!empty($regola_3m))
+else {
+$pers_min = (string) risul_query($regola_esistente,0,'iddatafine');
+$pers_def = $num_persone;
+} # fine else if (!empty($regola_3m))
+if ($pers_def and $pers_min > $pers_def) {
+$inserire = "NO";
+echo mex("Il numero di persone minimo",$pag)." ($pers_min) ".mex("è maggiore del numero di persone predefinito",$pag)." ($pers_def).<br>";
+} # fine if ($pers_def and $pers_min > $pers_def)
+} # fine if ((!isset($inserire) or $inserire != "NO") and $num_regole_esistente)
 if (!isset($inserire) or $inserire != "NO") {
 $regola2_esistente = esegui_query("select * from $tableregole where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
 if (numlin_query($regola2_esistente)) {
@@ -778,23 +797,33 @@ else $app_compatibile = 1;
 if (!$app_compatibile) echo "<br><b class=\"colwarn\">".mex("Attenzione",$pag)."</b>: ".lcfirst(mex("Non ci sono appartamenti con le caratteristiche richieste",'unit.php'))." ".mex("nella regola di assegnazione 2 di questa tariffa",$pag).".<br>";
 elseif ($app_piccoli) echo "<br><b class=\"colwarn\">".mex("Attenzione",$pag)."</b>: ".mex("ci sono appartamenti",'unit.php')." (<b>".substr($app_piccoli,2)."</b>) ".mex("nella regola 2 di questa tariffa che non possono ospitare",$pag)." $num_persone ".mex("persone",$pag).".<br>";
 } # fine if (numlin_query($regola2_esistente))
+if (!empty($regola_3m)) $campo = 'iddatafine';
+else $campo = 'iddatainizio';
 if ($num_regole_esistente != 0) {
-esegui_query("update $tableregole set iddatainizio = '".aggslashdb($num_persone)."' where tariffa_per_persone = '".aggslashdb($tipotariffa)."'");
+if (!$num_persone) {
+if (!$pers_def and !$pers_min) esegui_query("delete from $tableregole where tariffa_per_persone = '".aggslashdb($tipotariffa)."'");
+else esegui_query("update $tableregole set $campo = NULL where tariffa_per_persone = '".aggslashdb($tipotariffa)."'");
+echo "<br>".mex("La regola di assegnazione",$pag)." 3 ".mex("è stata cancellata",$pag).".<br><br>";
+} # fine if (!$num_persone)
+else {
+esegui_query("update $tableregole set $campo = '".aggslashdb($num_persone)."' where tariffa_per_persone = '".aggslashdb($tipotariffa)."'");
 echo "<br>".mex("La regola di assegnazione",$pag)." 3 ".mex("è stata modificata",$pag).".<br><br>";
+} # fine else if (!$num_persone)
 } # fine if ($num_regole_esistente != 0)
 else {
 $idregole = esegui_query("select max(idregole) from $tableregole");
 $idregole = risul_query($idregole,0,0);
 $idregole = $idregole + 1;
-esegui_query("insert into $tableregole (idregole,tariffa_per_persone,iddatainizio) values ('$idregole','".aggslashdb($tipotariffa)."', '".aggslashdb($num_persone)."')");
+esegui_query("insert into $tableregole (idregole,tariffa_per_persone,$campo) values ('$idregole','".aggslashdb($tipotariffa)."', '".aggslashdb($num_persone)."')");
 echo "<br>".mex("La regola di assegnazione",$pag)." 3 ".mex("è stata inserita",$pag).".<br><br>";
 } # fine else if ($num_regole_esistente != 0)
 $aggiorna_ic_tar = 1;
 } # fine if (!isset($inserire) or $inserire != "NO")
-} # fine if (!empty($regola_3) and $priv_mod_reg2 == "s")
+} # fine if ((!empty($regola_3) or !empty($regola_3m)) and $priv_mod_reg2 == "s")
 
 
 if (!empty($regola_4) and $id_utente == 1) {
+$inserire = "";
 if (substr($tipotariffa,0,7) != "tariffa" or controlla_num_pos(substr($tipotariffa,7)) == "NO") {
 $inserire = "NO";
 echo mex("Si deve scegliere la tariffa",$pag).".<br>";
@@ -881,7 +910,7 @@ $origine = "visualizza_tabelle.php?tipo_tabella=regole#hreg3";
 if ($origine == "tab_tariffa") {
 if (!empty($tipotariffa_regola2)) $mostra_solo_regola = 2;
 if (!empty($tipotariffa_regola3)) $mostra_solo_regola = 3;
-$origine = "tab_tariffe.php?numtariffa1=".htmlspecialchars(substr($tipotariffa_regola2.fixset($tipotariffa_regola3),7));
+$origine = "tab_tariffe.php?numtariffa1=".htmlspecialchars(substr(fixstr($tipotariffa_regola2).fixstr($tipotariffa_regola3),7));
 } # fine if ($origine == "tab_tariffa")
 if (substr($origine,0,3) == "ic_") {
 $orig = explode("_",$origine);
@@ -1393,6 +1422,32 @@ document.write('<div id=\"tab_appb\" style=\"visibility: hidden;\"><\/div>');
 
 
 if ((!$mostra_solo_regola or $mostra_solo_regola == 3) and $priv_mod_reg2 == "s") {
+$lista_tariffe3 = "";
+for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa = $numtariffa + 1) {
+if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[$numtariffa])) {
+$tariffa = "tariffa".$numtariffa;
+$tariffa_vedi = mex("tariffa","prenota.php").$numtariffa;
+$nometariffa = risul_query($rigatariffe,0,$tariffa);
+if ($nometariffa != "") $nometariffa_vedi = " ($nometariffa)";
+else $nometariffa_vedi = "";
+$lista_tariffe3 .= "<option value=\"$tariffa\">$tariffa_vedi$nometariffa_vedi</option>";
+} # fine if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[$numtariffa]))
+} # fine for $numtariffa
+$lista_tar_reg3 = "";
+$lista_tar_reg3min = "";
+$regole3 = esegui_query("select * from $tableregole where tariffa_per_persone != ''");
+$num_regole3 = numlin_query($regole3);
+for ($num1 = 0 ; $num1 < $num_regole3 ; $num1++) {
+$tariffa = risul_query($regole3,$num1,'tariffa_per_persone');
+if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[substr($tariffa,7)])) {
+$persone = risul_query($regole3,$num1,'iddatainizio');
+if ($persone) $lista_tar_reg3 .= "if (tariffa == \"$tariffa\") txt_box.value = \"$persone\";
+";
+$minpers = risul_query($regole3,$num1,'iddatafine');
+if ($minpers) $lista_tar_reg3min .= "if (tariffa == \"$tariffa\") txt_box.value = \"$minpers\";
+";
+} # fine if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[substr($tariffa,7)]))
+} # fine for $num1
 echo "
 <script type=\"text/javascript\">
 <!--
@@ -1404,62 +1459,89 @@ var txt_box = document.getElementById(\"v3\");
 if (tariffa == '') txt_box.disabled = true;
 else txt_box.disabled = false;
 txt_box.value = \"\";
-";
-$regole3 = esegui_query("select * from $tableregole where tariffa_per_persone != ''");
-$num_regole3 = numlin_query($regole3);
-for ($num1 = 0 ; $num1 < $num_regole3 ; $num1++) {
-$tariffa = risul_query($regole3,$num1,'tariffa_per_persone');
-if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[substr($tariffa,7)])) {
-$persone = risul_query($regole3,$num1,'iddatainizio');
-echo "if (tariffa == \"$tariffa\") txt_box.value = \"$persone\";
-";
-} # fine if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[substr($tariffa,7)]))
-} # fine for $num1
-echo "}
+$lista_tar_reg3
+}
+function aggiorna_val_reg3m () {
+var sel_tar = document.getElementById(\"t3m\");
+var num_sel = sel_tar.selectedIndex;
+var tariffa = sel_tar.options[num_sel].value;
+var txt_box = document.getElementById(\"v3m\");
+if (tariffa == '') txt_box.disabled = true;
+else txt_box.disabled = false;
+txt_box.value = \"\";
+$lista_tar_reg3min
+}
 -->
 </script>
 
-<div style=\"text-align: center;\" id=\"hreg3\">".mex("Regola di assegnazione",$pag)." <b>3</b> (".mex("numero di persone",$pag).").</div><br>
-<form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div>
+<div style=\"text-align: center;\" id=\"hreg3\">".mex("Regola di assegnazione",$pag)." <b>3</b> (".mex("numero di persone",$pag).").</div><br>";
+if (empty($tipotariffa_regola3) or empty($nor3)) {
+echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"inserisci\" value=\"SI\">";
 if ($origine) echo "<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine)."\">";
 echo mex("Quando si sceglie la tariffa",$pag)."
 <select name=\"tipotariffa\" id=\"t3\" onchange=\"aggiorna_val_reg3()\">
-<option value=\"\" selected>----</option>";
-for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa = $numtariffa + 1) {
-if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[$numtariffa])) {
-$tariffa = "tariffa".$numtariffa;
-$tariffa_vedi = mex("tariffa","prenota.php").$numtariffa;
-$nometariffa = risul_query($rigatariffe,0,$tariffa);
-if ($nometariffa != "") $nometariffa_vedi = " ($nometariffa)";
-else $nometariffa_vedi = "";
-echo "
-<option value=\"$tariffa\">$tariffa_vedi$nometariffa_vedi</option>";
-} # fine if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[$numtariffa]))
-} # fine for $numtariffa
-echo "</select>
+<option value=\"\" selected>----</option>
+$lista_tariffe3
+</select>
  ".mex("assegna automaticamente come numero di persone",$pag)."
  <input type=\"text\" id=\"v3\" name=\"num_persone\" size=\"5\">
- ".mex("se non si inserisce nessun altro numero",$pag).".<br>";
+ ".mex("se non si inserisce nessun altro numero",$pag).".";
 echo "<script type=\"text/javascript\">
 <!--
 var txt_box = document.getElementById(\"v3\");
 txt_box.disabled = true;
 -->
 </script>
-<div style=\"text-align: center;\">
 <button class=\"irul\" type=\"submit\" name=\"regola_3\" value=\"1\"><div>".mex("Inserisci o modifica la regola",$pag)." 3</div></button>
-</div></div></form><hr style=\"width: 95%\">";
+</div></form>
+<div style=\"height: 18px;\"></div>";
+} # fine if (empty($tipotariffa_regola3) or empty($nor3))
+if (empty($tipotariffa_regola3) or empty($nor3m)) {
+echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div>
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"inserisci\" value=\"SI\">";
+if ($origine) echo "<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine)."\">";
+echo mex("Quando si sceglie la tariffa",$pag)."
+<select name=\"tipotariffa\" id=\"t3m\" onchange=\"aggiorna_val_reg3m()\">
+<option value=\"\" selected>----</option>
+$lista_tariffe3
+</select>
+ ".mex("non permettere l'inserimento di prenotazioni con meno di",$pag)."
+ <input type=\"text\" id=\"v3m\" name=\"num_persone\" size=\"5\">
+ ".mex("persone",$pag).".";
+echo "<script type=\"text/javascript\">
+<!--
+var txt_box = document.getElementById(\"v3m\");
+txt_box.disabled = true;
+-->
+</script>
+<button class=\"irul\" type=\"submit\" name=\"regola_3m\" value=\"1\"><div>".mex("Inserisci o modifica la regola",$pag)." 3</div></button>
+</div></form>
+<div style=\"height: 6px;\"></div>";
+} # fine if (empty($tipotariffa_regola3) or empty($nor3m))
+echo "<hr style=\"width: 95%\">";
 
 if (!empty($tipotariffa_regola3) and preg_replace("/tariffa[0-9]+/","",$tipotariffa_regola3) == "") {
 echo "<script type=\"text/javascript\">
 <!--
-var sel_tr3 = document.getElementById(\"t3\");
+";
+if (empty($nor3)) {
+echo "var sel_tr3 = document.getElementById(\"t3\");
 sel_tr3.value = '$tipotariffa_regola3';
 aggiorna_val_reg3();
--->
+";
+} # fine if (empty($nor3))
+if (empty($nor3m)) {
+echo "var sel_tr3m = document.getElementById(\"t3m\");
+sel_tr3m.value = '$tipotariffa_regola3';
+aggiorna_val_reg3m();
+";
+} # fine if (empty($nor3m))
+echo "-->
 </script>
 ";
 } # fine if (!empty($tipotariffa_regola3) and...
