@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -56,9 +56,10 @@ define('C_BACKUP_E_MODELLI_CON_NUOVI_DATI',"SI");
 define('C_CREA_SUBORDINAZIONI',"SI");
 define('C_CREA_NUOVI_APP',"SI");
 define('C_URL_NUOVI_APP',"");
+define('C_CREA_ANNO_MANUALMENTE',"NO");
 define('C_CREA_ANNO_NON_ATTUALE',"SI");
 define('C_PRIMO_ANNO_CREATO',2001);
-define('C_CANCELLA_ANNO_ATTUALE',"SI");
+define('C_CANCELLA_ANNO_ATTUALE',"NO");
 define('C_CAMBIA_TIPO_PERIODI',"SI");
 define('C_DISABILITA_PASS_ADMIN',"SI");
 define('C_MOSTRA_COPYRIGHT',"SI"); # You are not authorized to remove the copyright notice. Ask info@digitaldruid.net
@@ -93,11 +94,12 @@ define('C_URL_FAVICON',"");
 define('C_SEC_LIMITE_LIBERA_APP',"");
 define('C_LIMITE_BACKUP_GIORNALIERI',0);
 define('C_LIMITE_CHIAMATE_API_AL_MINUTO',0);
-# può essere SI, NO o "spf: ..." con i campi spf (separati da spazi) che devono esistere nel dominio dell'email da mascherare
-if (!defined('C_MASCHERA_EMAIL')) define('C_MASCHERA_EMAIL',"");
+# can be "SI", "NO" or "spf: ..." with spf fields (separated by spaces) that must exists in the domain of the masquerading email
+#if (!defined('C_MASCHERA_EMAIL')) define('C_MASCHERA_EMAIL',"spf: a:mail.digitaldruid.net +ip4:88.80.188.111");
 define('C_LIB_MERCADOPAGO',"");
 define('C_URL_MODULO_PAYBOX',"http://");
 define('C_NASCONDI_MARCA',"");
+define('C_OPZIONI_NASCONDI_MARCA',"n"); # 1: s-n open ext module for credit cards in new window yes-no
 define('C_DISABILITA_COD_EMAIL_MODELLI',"NO");
 define('C_PASSWORD_BOOKINGCOM_IC',"");
 define('C_PASSWORD_EXPEDIA_IC',"");
