@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -39,30 +39,30 @@ $mess_dati_form .= "<input type=\"hidden\" name=\"inizioperiodo$n_t\" value=\"".
 <input type=\"hidden\" name=\"spezzetta$n_t\" value=\"".htmlspecialchars(fixstr(${"spezzetta".$n_t}))."\">";
 } # fine if ($manda_dati_assegnazione != "NO")
 for ($num_catp = 0 ; $num_catp < (int) fixset($num_categorie_persone) ; $num_catp++) {
-$mess_dati_form .= "<input type=\"hidden\" name=\"cat$num_catp"."_numpers$n_t\" value=\"".htmlspecialchars(${"cat$num_catp"."_numpers".$n_t})."\">";
+$mess_dati_form .= "<input type=\"hidden\" name=\"cat$num_catp"."_numpers$n_t\" value=\"".htmlspecialchars(fixstr(${"cat$num_catp"."_numpers".$n_t}))."\">";
 } # fine $num_catp
-$mess_dati_form .= "<input type=\"hidden\" name=\"tipo_sconto$n_t\" value=\"".htmlspecialchars(${"tipo_sconto".$n_t})."\">
-<input type=\"hidden\" name=\"sconto$n_t\" value=\"".htmlspecialchars(${"sconto".$n_t})."\">
-<input type=\"hidden\" name=\"tipo_val_sconto$n_t\" value=\"".htmlspecialchars(${"tipo_val_sconto".$n_t})."\">
+$mess_dati_form .= "<input type=\"hidden\" name=\"tipo_sconto$n_t\" value=\"".htmlspecialchars(fixstr(${"tipo_sconto".$n_t}))."\">
+<input type=\"hidden\" name=\"sconto$n_t\" value=\"".htmlspecialchars(fixstr(${"sconto".$n_t}))."\">
+<input type=\"hidden\" name=\"tipo_val_sconto$n_t\" value=\"".htmlspecialchars(fixstr(${"tipo_val_sconto".$n_t}))."\">
 <input type=\"hidden\" name=\"conferma_prenota$n_t\" value=\"".htmlspecialchars(fixstr(${"conferma_prenota".$n_t}))."\">
-<input type=\"hidden\" name=\"caparra$n_t\" value=\"".htmlspecialchars(${"caparra".$n_t})."\">
-<input type=\"hidden\" name=\"tipo_val_caparra$n_t\" value=\"".htmlspecialchars(${"tipo_val_caparra".$n_t})."\">
-<input type=\"hidden\" name=\"commissioni$n_t\" value=\"".htmlspecialchars(${"commissioni".$n_t})."\">
-<input type=\"hidden\" name=\"tipo_val_commissioni$n_t\" value=\"".htmlspecialchars(${"tipo_val_commissioni".$n_t})."\">
-<input type=\"hidden\" name=\"giorno_stima_checkin$n_t\" value=\"".htmlspecialchars(${"giorno_stima_checkin".$n_t})."\">
-<input type=\"hidden\" name=\"ora_stima_checkin$n_t\" value=\"".htmlspecialchars(${"ora_stima_checkin".$n_t})."\">
-<input type=\"hidden\" name=\"min_stima_checkin$n_t\" value=\"".htmlspecialchars(${"min_stima_checkin".$n_t})."\">
-<input type=\"hidden\" name=\"num_commenti$n_t\" value=\"".htmlspecialchars(${"num_commenti".$n_t})."\">";
-for ($num_comm = 1 ; $num_comm <= ${"num_commenti".$n_t} ; $num_comm++) {
+<input type=\"hidden\" name=\"caparra$n_t\" value=\"".htmlspecialchars(fixstr(${"caparra".$n_t}))."\">
+<input type=\"hidden\" name=\"tipo_val_caparra$n_t\" value=\"".htmlspecialchars(fixstr(${"tipo_val_caparra".$n_t}))."\">
+<input type=\"hidden\" name=\"commissioni$n_t\" value=\"".htmlspecialchars(fixstr(${"commissioni".$n_t}))."\">
+<input type=\"hidden\" name=\"tipo_val_commissioni$n_t\" value=\"".htmlspecialchars(fixstr(${"tipo_val_commissioni".$n_t}))."\">
+<input type=\"hidden\" name=\"giorno_stima_checkin$n_t\" value=\"".htmlspecialchars(fixstr(${"giorno_stima_checkin".$n_t}))."\">
+<input type=\"hidden\" name=\"ora_stima_checkin$n_t\" value=\"".htmlspecialchars(fixstr(${"ora_stima_checkin".$n_t}))."\">
+<input type=\"hidden\" name=\"min_stima_checkin$n_t\" value=\"".htmlspecialchars(fixstr(${"min_stima_checkin".$n_t}))."\">
+<input type=\"hidden\" name=\"num_commenti$n_t\" value=\"".htmlspecialchars(fixstr(${"num_commenti".$n_t}))."\">";
+for ($num_comm = 1 ; $num_comm <= (int) fixset(${"num_commenti".$n_t}) ; $num_comm++) {
 $mess_dati_form .= "<input type=\"hidden\" name=\"tipo_commento$num_comm"."_$n_t\" value=\"".htmlspecialchars(fixstr(${"tipo_commento".$num_comm."_".$n_t}))."\">";
-if (!@get_magic_quotes_gpc()) $mess_dati_form .= "<input type=\"hidden\" name=\"commento$num_comm"."_$n_t\" value=\"".htmlspecialchars(${"commento".$num_comm."_".$n_t})."\">";
-else $mess_dati_form .= "<input type=\"hidden\" name=\"commento$num_comm"."_$n_t\" value=\"".htmlspecialchars(stripslashes(${"commento".$num_comm."_".$n_t}))."\">";
+if (!@get_magic_quotes_gpc()) $mess_dati_form .= "<input type=\"hidden\" name=\"commento$num_comm"."_$n_t\" value=\"".htmlspecialchars(fixstr(${"commento".$num_comm."_".$n_t}))."\">";
+else $mess_dati_form .= "<input type=\"hidden\" name=\"commento$num_comm"."_$n_t\" value=\"".htmlspecialchars(stripslashes(fixstr(${"commento".$num_comm."_".$n_t})))."\">";
 } # fine for $num_comm
 if (!@get_magic_quotes_gpc()) $mess_dati_form .= "<input type=\"hidden\" name=\"met_paga_caparra$n_t\" value=\"".htmlspecialchars(fixstr(${"met_paga_caparra".$n_t}))."\">";
-else $mess_dati_form .= "<input type=\"hidden\" name=\"met_paga_caparra$n_t\" value=\"".htmlspecialchars(stripslashes(${"met_paga_caparra".$n_t}))."\">";
+else $mess_dati_form .= "<input type=\"hidden\" name=\"met_paga_caparra$n_t\" value=\"".htmlspecialchars(stripslashes(fixstr(${"met_paga_caparra".$n_t})))."\">";
 if (!@get_magic_quotes_gpc()) $mess_dati_form .= "<input type=\"hidden\" name=\"origine_prenota$n_t\" value=\"".htmlspecialchars(fixstr(${"origine_prenota".$n_t}))."\">";
-else $mess_dati_form .= "<input type=\"hidden\" name=\"origine_prenota$n_t\" value=\"".htmlspecialchars(stripslashes(${"origine_prenota".$n_t}))."\">";
-for ($numca = 1 ; $numca <= $numcostiagg ; $numca++) {
+else $mess_dati_form .= "<input type=\"hidden\" name=\"origine_prenota$n_t\" value=\"".htmlspecialchars(stripslashes(fixstr(${"origine_prenota".$n_t})))."\">";
+for ($numca = 1 ; $numca <= (int) fixset($numcostiagg) ; $numca++) {
 $costoagg = "costoagg".$numca."_".$n_t;
 $idcostoagg = "idcostoagg".$numca."_".$n_t;
 $numsettimane = "numsettimane".$numca."_".$n_t;
@@ -77,12 +77,12 @@ if (!empty($$id_periodi_costo)) $mess_dati_form .= "<input type=\"hidden\" name=
 if (strcmp(fixstr($$catpers_ca),"")) $mess_dati_form .= "<input type=\"hidden\" name=\"$catpers_ca\" value=\"".htmlspecialchars($$catpers_ca)."\">";
 } # fine for $numca
 } # fine for $n_t
-$mess_dati_form .= "<input type=\"hidden\" name=\"numcostiagg\" value=\"".htmlspecialchars($numcostiagg)."\">
-<input type=\"hidden\" name=\"id_utente_ins\" value=\"$id_utente_ins\">
-<input type=\"hidden\" name=\"mos_tut_dat\" value=\"$mos_tut_dat\">
-<input type=\"hidden\" name=\"num_tipologie\" value=\"$num_tipologie\">";
+$mess_dati_form .= "<input type=\"hidden\" name=\"numcostiagg\" value=\"".htmlspecialchars(fixstr($numcostiagg))."\">
+<input type=\"hidden\" name=\"id_utente_ins\" value=\"".htmlspecialchars(fixstr($id_utente_ins))."\">
+<input type=\"hidden\" name=\"mos_tut_dat\" value=\"".htmlspecialchars(fixstr($mos_tut_dat))."\">
+<input type=\"hidden\" name=\"num_tipologie\" value=\"".htmlspecialchars(fixstr($num_tipologie))."\">";
 if ($manda_dati_assegnazione != "NO") $mess_dati_form .= "<input type=\"hidden\" name=\"prenota_vicine\" value=\"".htmlspecialchars(fixstr($prenota_vicine))."\">";
-else $mess_dati_form .= "<input type=\"hidden\" name=\"id_transazione\" value=\"$id_transazione\">";
+else $mess_dati_form .= "<input type=\"hidden\" name=\"id_transazione\" value=\"".htmlspecialchars(fixstr($id_transazione))."\">";
 if (isset($idmessaggi)) $mess_dati_form .= "<input type=\"hidden\" name=\"idmessaggi\" value=\"".htmlspecialchars($idmessaggi)."\">";
 if (isset($num_categorie_persone) and $num_categorie_persone > 1) $mess_dati_form .= "<input type=\"hidden\" name=\"num_categorie_persone\" value=\"".htmlspecialchars($num_categorie_persone)."\">";
 
