@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -21,7 +21,7 @@
 ##################################################################################
 
 
-#ini_set('display_errors','Off');
+#if (function_exists('ini_set')) @ini_set('display_errors','Off');
 #error_reporting(E_ALL ^ E_NOTICE);
 #error_reporting(E_ALL);
 if (function_exists('version_compare') and version_compare(PHP_VERSION, '8.0.0', '>=')) error_reporting(E_ALL & ~E_NOTICE & ~E_STRICT & ~E_DEPRECATED & ~E_WARNING);
@@ -82,17 +82,17 @@ $parole_sost = 0;
 
 #@include("./includes/costanti.php");
 #@include(C_DATI_PATH."/costanti.php");
-define('C_PHPR_VERSIONE_NUM',3.04);
-define('C_PHPR_VERSIONE_TXT',"3.0.4");
+define('C_PHPR_VERSIONE_NUM',3.05);
+define('C_PHPR_VERSIONE_TXT',"3.0.5");
 
 if (!isset($nome_utente_phpr)) $nome_utente_phpr = "";
 if (!isset($password_phpr)) $password_phpr = "";
 if (!isset($id_sessione)) $id_sessione = "";
 
-if (!function_exists('utf8_encode')) {
+/*if (!function_exists('utf8_encode')) {
 function utf8_encode ($testo) { return ($testo); }
 function utf8_decode ($testo) { return ($testo); }
-} # fine if (!function_exists('utf8_encode'))
+} # fine if (!function_exists('utf8_encode'))*/
 if (!function_exists('get_magic_quotes_gpc')) {
 function get_magic_quotes_gpc () { return 0; }
 } # fine if (!function_exists('get_magic_quotes_gpc'))
@@ -545,7 +545,7 @@ $nome_utente_login = "";
 
 
 if (!is_file(C_DATI_PATH."/abilita_login")) {
-if ($pag == "inizio.php" or $pag == "creadb.php" or @is_file(C_DATI_PATH."/selectperiodi$anno.1.php")) $id_utente = 1;
+if ($pag == "inizio.php" or $pag == "creadb.php" or $pag == "aggiorna.php" or @is_file(C_DATI_PATH."/selectperiodi$anno.1.php")) $id_utente = 1;
 else echo "<br>The requested year does not exist.<br><br><a href=\"./inizio.php\">Go back</a><br>";
 } # fine if (!is_file(C_DATI_PATH."/abilita_login"))
 
@@ -648,6 +648,7 @@ $id_cliente = crea_val_casuale();
 if (function_exists('version_compare') and version_compare(PHP_VERSION, '5.2.0', '>=')) setcookie('HD_session_'.substr($id_sessione,30),$id_cliente,0,'','',1,1);
 else setcookie('HD_session_'.substr($id_sessione,30),$id_cliente,0,'','',1);
 if (empty($test_cookie) or fixset($_COOKIE['HD_test']) != $test_cookie) $id_cliente = "-$id_cliente";
+else $cookie_sess = 1;
 esegui_query("insert into $tablesessioni (idsessioni,idcliente,idutente,indirizzo_ip,tipo_conn,user_agent,ultimo_accesso) values ('$id_sessione','$id_cliente','$id_utente','$REMOTE_ADDR','$tipo_conn','$HTTP_USER_AGENT','$ultimo_accesso')","",$id_utente);
 } # fine if (C_USA_COOKIES)
 else {
@@ -853,7 +854,7 @@ if ($tema[1] and $tema[1] != "base" and @is_dir("./themes/".$tema[1]."/php")) in
 else include("./includes/foot.php");
 } # fine if ($messaggio_errore or isset($mostra_form_login))
 
-if ($id_utente and ($lingua[$id_utente] == "ita" or @is_dir("./includes/lang/".$lingua[$id_utente]))) $lingua_mex = $lingua[$id_utente];
+if ($id_utente and (isset($lingua[$id_utente]) and ($lingua[$id_utente] == "ita" or @is_dir("./includes/lang/".$lingua[$id_utente])))) $lingua_mex = $lingua[$id_utente];
 } # fine else if (!is_file(C_DATI_PATH."/abilita_login"))
 
 
@@ -981,13 +982,16 @@ fclose($filelock);
 
 
 
-function elimina_caratteri_slash ($var) {
+function elimina_caratteri_slash (&$var) {
 
-$var = str_replace ("'","",(string) $var);
-$var = str_replace ("\\","",$var);
-$var = str_replace ("\"","",$var);
+if (isset($var)) {
+$vr = str_replace ("'","",(string) $var);
+$vr = str_replace ("\\","",$vr);
+$vr = str_replace ("\"","",$vr);
+} # fine if (isset($var))
+else $vr = "";
 
-return $var;
+return $vr;
 
 } # fine function elimina_caratteri_slash
 
@@ -1089,7 +1093,7 @@ else if (!$standalone_dates_menu) $current_dates_menu++;
 
 if ($blank_selected) $date_selected = "";
 $num_periodi_date = count($d_increment);
-if (($num_periodi_date > 1 or $d_increment[0] > 1) and $date_selected) {
+if (($num_periodi_date > 1 or (isset($d_increment[0]) and $d_increment[0] > 1)) and $date_selected) {
 for ($num1 = 0 ; $num1 < $num_periodi_date ; $num1++) {
 for ($num2 = 0 ; $num2 < $n_dates_menu[$num1] ; $num2++) {
 $data_corr = date("Y-m-d",mktime(0,0,0,($m_ini_menu[$num1] + 1),($d_ini_menu[$num1] + ($num2 * $d_increment[$num1])),$y_ini_menu[$num1]));
@@ -1103,7 +1107,7 @@ $data_prec = $data_corr;
 } # fine for $num2
 if ($data_corr == $date_selected or $data_prec == $date_selected) break;
 } # fine for $num1
-} # fine if (($num_periodi_date > 1 or $d_increment[0] > 1) and $date_selected)
+} # fine if (($num_periodi_date > 1 or (isset($d_increment[0]) and...
 
 if ($tema[$id_utente] != "base") include("./themes/".$tema[$id_utente]."/php/selectperiod.php");
 
