@@ -22,6 +22,15 @@
 
 
 
+if (function_exists('mb_convert_case')) {
+function par_maius (&$str) { return mb_convert_case($str,MB_CASE_TITLE); }
+} # fine if (function_exists('mb_convert_case'))
+else {
+function par_maius (&$str) { return ucwords($str); }
+} # fine else if (function_exists('mb_convert_case'))
+
+
+
 
 function inserisci_dati_cliente (&$cognome,&$nome,$soprannome,$titolo_cli,$sesso,$mesenascita,$giornonascita,$annonascita,&$nazionenascita,&$cittanascita,&$regionenascita,$documento,$tipodoc,$mesescaddoc,$giornoscaddoc,$annoscaddoc,&$cittadoc,&$regionedoc,&$nazionedoc,&$nazionalita,&$lingua_cli,&$nazione,&$citta,&$regione,&$via,$nomevia,$numcivico,$cap,$telefono,$telefono2,$telefono3,$fax,$email,$email2,$email_cert,$cod_fiscale,$partita_iva,$max_num_ordine,$id_utente_ins,$attiva_prefisso_clienti,$prefisso_clienti,$idclienti="",$valida="",$campi_pers_vett="") {
 global $lingua_mex,$HOSTNAME,$id_utente,$PHPR_TAB_PRE;
@@ -103,19 +112,19 @@ else {
 $idclienti = esegui_query("select max(idclienti) from $tableclienti");
 $idclienti = risul_query($idclienti,0,0) + 1;
 } # fine else if (numlin_query($idclienti) == 0)
-$cognome_maius = trim(ucwords($cognome));
+$cognome_maius = trim(par_maius($cognome));
 if ($attiva_prefisso_clienti == "p") $cognome_maius = $prefisso_clienti.$cognome_maius;
 if ($attiva_prefisso_clienti == "s") $cognome_maius = $cognome_maius.$prefisso_clienti;
 esegui_query("insert into $tableclienti (idclienti,cognome,idclienti_compagni,datainserimento,hostinserimento,utente_inserimento) values ('$idclienti','".aggslashdb(substr($cognome_maius,0,70))."',',','$datainserimento','$HOSTNAME','$id_utente_ins')");
 } # fine if (!$idclienti)
 elseif ($cognome) {
-$cognome_maius = trim(ucwords($cognome));
+$cognome_maius = trim(par_maius($cognome));
 if ($attiva_prefisso_clienti == "p") $cognome_maius = $prefisso_clienti.$cognome_maius;
 if ($attiva_prefisso_clienti == "s") $cognome_maius = $cognome_maius.$prefisso_clienti;
 esegui_query("update $tableclienti set cognome = '".aggslashdb(substr($cognome_maius,0,70))."' where idclienti = '$idclienti' ");
 } # fine elseif ($cognome)
 if ($nome) {
-$nome_maius = trim(ucwords($nome));
+$nome_maius = trim(par_maius($nome));
 esegui_query("update $tableclienti set nome = '".aggslashdb(substr($nome_maius,0,70))."' where idclienti = '$idclienti' ");
 } # fine if ($nome)
 if ($soprannome) {
@@ -155,24 +164,20 @@ $datanascita = aggslashdb($datanascita);
 esegui_query("update $tableclienti set datanascita = '$datanascita' where idclienti = '$idclienti' ");
 } # fine if ($mesenascita and ...
 if ($nazionenascita) {
-$nazionenascita_maius = trim(ucwords($nazionenascita));
-$nazionenascita_maius = aggslashdb($nazionenascita_maius);
-esegui_query("update $tableclienti set nazionenascita = '$nazionenascita_maius' where idclienti = '$idclienti' ");
+$nazionenascita_maius = trim(par_maius($nazionenascita));
+esegui_query("update $tableclienti set nazionenascita = '".aggslashdb(substr($nazionenascita_maius,0,70))."' where idclienti = '$idclienti' ");
 } # fine if ($nazionenascita)
 if ($cittanascita) {
-$cittanascita_maius = trim(ucwords($cittanascita));
-$cittanascita_maius = aggslashdb($cittanascita_maius);
-esegui_query("update $tableclienti set cittanascita = '$cittanascita_maius' where idclienti = '$idclienti' ");
+$cittanascita_maius = trim(par_maius($cittanascita));
+esegui_query("update $tableclienti set cittanascita = '".aggslashdb(substr($cittanascita_maius,0,70))."' where idclienti = '$idclienti' ");
 } # fine if ($cittanascita)
 if ($regionenascita) {
-$regionenascita_maius = trim(ucwords($regionenascita));
-$regionenascita_maius = aggslashdb($regionenascita_maius);
-esegui_query("update $tableclienti set regionenascita = '$regionenascita_maius' where idclienti = '$idclienti' ");
+$regionenascita_maius = trim(par_maius($regionenascita));
+esegui_query("update $tableclienti set regionenascita = '".aggslashdb(substr($regionenascita_maius,0,70))."' where idclienti = '$idclienti' ");
 } # fine if ($regionenascita)
 if ($documento) {
-if ($tipodoc) esegui_query("update $tableclienti set tipodoc = '".aggslashdb($tipodoc)."' where idclienti = '$idclienti' ");
-$documento = aggslashdb($documento);
-esegui_query("update $tableclienti set documento = '$documento' where idclienti = '$idclienti' ");
+if ($tipodoc) esegui_query("update $tableclienti set tipodoc = '".aggslashdb(substr($tipodoc0,70))."' where idclienti = '$idclienti' ");
+esegui_query("update $tableclienti set documento = '".aggslashdb(substr($documento,0,70))."' where idclienti = '$idclienti' ");
 } # fine if ($documento)
 if ($mesescaddoc and $giornoscaddoc and $annoscaddoc) {
 $datascaddoc = date("Y-m-d",mktime(0,0,0,$mesescaddoc,$giornoscaddoc,$annoscaddoc));
@@ -180,44 +185,40 @@ $datascaddoc = aggslashdb($datascaddoc);
 esegui_query("update $tableclienti set scadenzadoc = '$datascaddoc' where idclienti = '$idclienti' ");
 } # fine if ($mesescaddoc and ...
 if ($nazionedoc) {
-$nazionedoc_maius = trim(ucwords($nazionedoc));
-$nazionedoc_maius = aggslashdb($nazionedoc_maius);
-esegui_query("update $tableclienti set nazionedoc = '$nazionedoc_maius' where idclienti = '$idclienti' ");
+$nazionedoc_maius = trim(par_maius($nazionedoc));
+esegui_query("update $tableclienti set nazionedoc = '".aggslashdb(substr($nazionedoc_maius,0,70))."' where idclienti = '$idclienti' ");
 } # fine if ($nazionedoc)
 if ($cittadoc) {
-$cittadoc_maius = trim(ucwords($cittadoc));
-$cittadoc_maius = aggslashdb($cittadoc_maius);
-esegui_query("update $tableclienti set cittadoc = '$cittadoc_maius' where idclienti = '$idclienti' ");
+$cittadoc_maius = trim(par_maius($cittadoc));
+esegui_query("update $tableclienti set cittadoc = '".aggslashdb(substr($cittadoc_maius,0,70))."' where idclienti = '$idclienti' ");
 } # fine if ($cittadoc)
 if ($regionedoc) {
-$regionedoc_maius = trim(ucwords($regionedoc));
-$regionedoc_maius = aggslashdb($regionedoc_maius);
-esegui_query("update $tableclienti set regionedoc = '$regionedoc_maius' where idclienti = '$idclienti' ");
+$regionedoc_maius = trim(par_maius($regionedoc));
+esegui_query("update $tableclienti set regionedoc = '".aggslashdb(substr($regionedoc_maius,0,70))."' where idclienti = '$idclienti' ");
 } # fine if ($regionedoc)
 if ($nazionalita) {
-$nazionalita_maius = trim(ucwords($nazionalita));
-$nazionalita_maius = aggslashdb($nazionalita_maius);
-esegui_query("update $tableclienti set nazionalita = '$nazionalita_maius' where idclienti = '$idclienti' ");
+$nazionalita_maius = trim(par_maius($nazionalita));
+esegui_query("update $tableclienti set nazionalita = '".aggslashdb(substr($nazionalita_maius,0,70))."' where idclienti = '$idclienti' ");
 } # fine if ($nazionalita)
 if ($lingua_cli) {
 if (preg_replace("/[a-z]{2,3}/","",$lingua_cli) == "") {
 if ($lingua_cli == $lingua_mex or $lingua_cli == "ita" or @is_dir("./includes/lang/$lingua_cli")) {
-esegui_query("update $tableclienti set lingua = '".aggslashdb($lingua_cli)."' where idclienti = '$idclienti' ");
+esegui_query("update $tableclienti set lingua = '".aggslashdb(substr($lingua_cli,0,14))."' where idclienti = '$idclienti' ");
 } # fine if ($lingua == $lingua_mex or $lingua_cli == "ita" or...
 else $lingua_cli = "";
 } # fine if (preg_replace("/[a-z]{2,3}/","",$lingua_cli) == "")
 else $lingua_cli = "";
 } # fine if ($lingua_cli)
 if ($nazione) {
-$nazione_maius = trim(ucwords($nazione));
+$nazione_maius = trim(par_maius($nazione));
 esegui_query("update $tableclienti set nazione = '".aggslashdb(substr($nazione_maius,0,70))."' where idclienti = '$idclienti' ");
 } # fine if ($nazione)
 if ($citta) {
-$citta_maius = trim(ucwords($citta));
+$citta_maius = trim(par_maius($citta));
 esegui_query("update $tableclienti set citta = '".aggslashdb(substr($citta_maius,0,70))."' where idclienti = '$idclienti' ");
 } # fine if ($citta)
 if ($regione) {
-$regione_maius = trim(ucwords($regione));
+$regione_maius = trim(par_maius($regione));
 esegui_query("update $tableclienti set regione = '".aggslashdb(substr($regione_maius,0,70))."' where idclienti = '$idclienti' ");
 } # fine if ($regione)
 if ($nomevia) {
@@ -227,7 +228,7 @@ if (isset($ordine_strada) and $ordine_strada == 2) $via = $nomevia." ".$via;
 else $via = $via." ".$nomevia;
 } # fine if (strcmp((string) $via,""))
 else $via = $nomevia;
-$via_maius = trim(ucwords($via));
+$via_maius = trim(par_maius($via));
 esegui_query("update $tableclienti set via = '".aggslashdb(substr($via_maius,0,70))."' where idclienti = '$idclienti' ");
 } # fine if ($nomevia)
 if ($numcivico) esegui_query("update $tableclienti set numcivico = '".aggslashdb(substr($numcivico,0,30))."' where idclienti = '$idclienti' ");
@@ -242,9 +243,9 @@ $email2 = aggslashdb($email2);
 if ($email2) esegui_query("update $tableclienti set email2 = '$email2' where idclienti = '$idclienti' ");
 $email_cert = aggslashdb($email_cert);
 if ($email_cert) esegui_query("update $tableclienti set email3 = '$email_cert' where idclienti = '$idclienti' ");
-$cod_fiscale = aggslashdb($cod_fiscale);
+$cod_fiscale = aggslashdb(substr($cod_fiscale,0,50));
 if ($cod_fiscale) esegui_query("update $tableclienti set cod_fiscale = '$cod_fiscale' where idclienti = '$idclienti' ");
-$partita_iva = aggslashdb($partita_iva);
+$partita_iva = aggslashdb(substr($partita_iva,0,50));
 if ($partita_iva) esegui_query("update $tableclienti set partita_iva = '$partita_iva' where idclienti = '$idclienti' ");
 if ($max_num_ordine) esegui_query("update $tableclienti set max_num_ordine = '".aggslashdb($max_num_ordine)."' where idclienti = '$idclienti' ");
 
