@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -242,7 +242,7 @@ $num_costi = numlin_query($costi);
 $num_costi_orig = $num_costi;
 for ($num1 = 0 ; $num1 < $num_costi_orig ; $num1++) {
 $associasett = risul_query($costi,$num1,'associasett',$tablecostiprenota);
-$settimane_costo = risul_query($costi,$num1,'settimane',$tablecostiprenota);
+$settimane_costo = (string) risul_query($costi,$num1,'settimane',$tablecostiprenota);
 if ($associasett == "s" and str_replace(",$id_periodo,","",$settimane_costo) == $settimane_costo) $num_costi--;
 else {
 $moltiplica = risul_query($costi,$num1,'moltiplica',$tablecostiprenota);
@@ -336,6 +336,7 @@ $prezzo_costo_sett = 0;
 $moltiplica = explode(",",$moltiplica);
 $num_lista_tariffe = 0;
 $num_sett = 1;
+$prezzo_giorn_costo_max = 0;
 for ($num1 = $idinizioperiodo ; $num1 <= $idfineperiodo ; $num1++) {
 if (str_replace(",".$num1.",","",$settimane_costo) != $settimane_costo) {
 if (!$moltiplica[$num_sett]) $moltiplica[$num_sett] = 0;
@@ -351,7 +352,7 @@ if ($prezzi_giorn) {
 $prezzo_costo_sett2 = $prezzo_costo_sett;
 if ($dati_ca[$num_costo]['tipo_val'] != "f") $prezzo_costo_sett2 = floor($prezzo_costo_sett2 / $dati_ca[$num_costo]['arrotonda']) * $dati_ca[$num_costo]['arrotonda'];
 $prezzo_giorn_costo_corr = $prezzo_costo_fisso + $prezzo_costo_sett2;
-if (empty($prezzo_giorn_costo_max) or $prezzo_giorn_costo_corr > $prezzo_giorn_costo_max) $prezzo_giorn_costo_max = $prezzo_giorn_costo_corr;
+if (!$prezzo_giorn_costo_max or $prezzo_giorn_costo_corr > $prezzo_giorn_costo_max) $prezzo_giorn_costo_max = $prezzo_giorn_costo_corr;
 $prezzi_giorn_costo .= ($prezzo_giorn_costo_corr * $moltiplica[$num_sett]).",";
 } # fine if ($prezzi_giorn)
 $num_sett++;
@@ -367,7 +368,7 @@ if ($prezzi_giorn) {
 $prezzi_giorn_costo = $prezzo_costo_fisso;
 if ($dati_ca[$num_costo]['numsett'] != "t") $prezzi_giorn_costo = "$settimane_costo,$prezzi_giorn_costo";
 } # fine if ($prezzi_giorn)
-$prezzo_costo_fisso = $prezzo_costo_fisso * $settimane_costo;
+$prezzo_costo_fisso = $prezzo_costo_fisso * (int) $settimane_costo;
 } # fine else if ($dati_ca[$num_costo]['associasett'] == "s")
 } # fine if ($dati_ca[$num_costo]['tipo'] == "s")
 elseif ($prezzi_giorn) {
@@ -544,23 +545,32 @@ $num_letti_agg[$num1] = $num_letti_agg[$num1] + $moltiplica_corr;
 
 if (!empty($dati_cat_pers['num'])) {
 if (strcmp((string) $catpers_ca,"")) $dati_ca[$num_costo]['cat_pers']['esist'][0] = 1;
-else $catpers_ca = $dati_ca[$num_costo]['cat_pers']['ord'][0];
+else {
+if (isset($dati_ca[$num_costo]['cat_pers']['ord'][0])) $catpers_ca = $dati_ca[$num_costo]['cat_pers']['ord'][0];
+else $catpers_ca = 0;
+} # fine else if (strcmp((string) $catpers_ca,""))
 if (!isset($num_letti_agg['catp'][$num1])) $num_letti_agg['catp'][$num1] = "";
 $num_letti_agg['catp'][$num1] .= " + $moltiplica_corr ";
-if ($dati_ca[$num_costo]['cat_pers']['esist'][0]) {
+if (!empty($dati_ca[$num_costo]['cat_pers']['esist'][0])) {
 if ($moltiplica_corr > 1) $num_letti_agg['catp'][$num1] .= $dati_cat_pers[$catpers_ca]['n_plur'];
 else $num_letti_agg['catp'][$num1] .= $dati_cat_pers[$catpers_ca]['n_sing'];
 if (!isset($num_letti_agg['catp_tot'][$num1][$catpers_ca])) $num_letti_agg['catp_tot'][$num1][$catpers_ca] = 0;
 $num_letti_agg['catp_tot'][$num1][$catpers_ca] += $moltiplica_corr;
 if (empty($num_letti_agg['catp_tot_max'][$catpers_ca]) or $num_letti_agg['catp_tot'][$num1][$catpers_ca] > $num_letti_agg['catp_tot_max'][$catpers_ca]) $num_letti_agg['catp_tot_max'][$catpers_ca] = $num_letti_agg['catp_tot'][$num1][$catpers_ca];
-} # fine if ($dati_ca[$num_costo]['cat_pers']['esist'][0])
+} # fine if (!empty($dati_ca[$num_costo]['cat_pers']['esist'][0]))
 else {
-if (!$num_letti_agg['catp_solo_esist']) {
+if (empty($num_letti_agg['catp_solo_esist'])) {
 if ($moltiplica_corr > 1) $num_letti_agg['catp'][$num1] .= $dati_ca[$num_costo]['cat_pers'][0]['n_plur'];
-else $num_letti_agg['catp'][$num1] .= $dati_ca[$num_costo]['cat_pers'][0]['n_sing'];
-} # fine if (!$num_letti_agg['catp_solo_esist'])
-$num_letti_agg['catp_tot'][$num1]['ex'][$dati_ca[$num_costo]['cat_pers'][0]['n_plur']] += $moltiplica_corr;
-} # fine if ($dati_ca[$num_costo]['cat_pers']['esist'][0])
+else {
+if (isset($dati_ca[$num_costo]['cat_pers'][0]['n_sing'])) $num_letti_agg['catp'][$num1] .= $dati_ca[$num_costo]['cat_pers'][0]['n_sing'];
+else $num_letti_agg['catp'][$num1] .= $dati_cat_pers[$catpers_ca]['n_sing'];
+} # fine else if ($moltiplica_corr > 1)
+} # fine if (empty($num_letti_agg['catp_solo_esist']))
+if (isset($dati_ca[$num_costo]['cat_pers'][0]['n_plur'])) $catpers_ca_corr = $dati_ca[$num_costo]['cat_pers'][0]['n_plur'];
+else $catpers_ca_corr = $dati_cat_pers[$catpers_ca]['n_plur'];
+if (!isset($num_letti_agg['catp_tot'][$num1]['ex'][$catpers_ca_corr])) $num_letti_agg['catp_tot'][$num1]['ex'][$catpers_ca_corr] = 0;
+$num_letti_agg['catp_tot'][$num1]['ex'][$catpers_ca_corr] += $moltiplica_corr;
+} # fine if (!empty($dati_ca[$num_costo]['cat_pers']['esist'][0]))
 } # fine if (!empty($dati_cat_pers['num']))
 
 if ($num_letti_agg[$num1] > $num_letti_agg['max']) {
@@ -577,7 +587,7 @@ $num_letti_agg['sett_max'] = $num1;
 function controlla_num_limite_costo ($tablecostiprenota,$tableprenota,$dati_ca,$num_costo,&$num_costi_presenti,$idinizioperiodo,$idfineperiodo,$settimane_costo,$moltiplica,$num_limite = "",$tra_anni = "") {
 
 $limite_rispettato = "SI";
-if ($num_limite == "") $num_limite = $dati_ca[$num_costo]['numlimite'];
+if (fixstr($num_limite) == "") $num_limite = fixset($dati_ca[$num_costo]['numlimite']);
 if ($num_limite) {
 if (!empty($dati_ca[$num_costo]['idntariffe'])) $idcostoagg = $dati_ca[$num_costo]['idntariffe'];
 else $idcostoagg = $dati_ca[$num_costo]['id'];
@@ -705,7 +715,7 @@ $num2++;
 } # fine for $num1
 } # fine if ($sett_periodipermessi)
 } # fine if ($dati_cap[$numca]['periodipermessi'])
-$dati_cap[$numca]['settimane'] = risul_query($costi,$numca,'settimane');
+$dati_cap[$numca]['settimane'] = (string) risul_query($costi,$numca,'settimane');
 $dati_cap[$numca]['moltiplica_costo'] = risul_query($costi,$numca,'moltiplica');
 if ($dati_cap[$numca]['associasett'] == "s") {
 $sett = explode(",",$dati_cap[$numca]['settimane']);
@@ -833,7 +843,7 @@ function controlla_beni_inventario_costo ($tablerelinventario,$dati_ca,$num_cost
 $beni_presenti = "SI";
 if ($dati_ca[$num_costo]['tipo_beniinv']) {
 if (!strcmp((string) $num_ripetizioni_costo,"")) $num_ripetizioni_costo = calcola_ripetizioni_costo($dati_ca,$num_costo,$idinizioperiodo,$idfineperiodo,$settimane_costo,$moltiplica);
-if (!strcmp((string) $beniinv_ripeti,"")) $beniinv_ripeti = $dati_ca[$num_costo]['beniinv_ripeti'];
+if (!strcmp((string) $beniinv_ripeti,"")) $beniinv_ripeti = fixset($dati_ca[$num_costo]['beniinv_ripeti']);
 if ($beniinv_ripeti) $num_ripetizioni_costo_diff = $num_ripetizioni_costo - $beniinv_ripeti;
 else $num_ripetizioni_costo_diff = $num_ripetizioni_costo;
 if ($num_ripetizioni_costo_diff) {
