@@ -110,7 +110,7 @@ return $dati_tariffe;
 
 
 
-function dati_regole2 (&$dati_r2,&$app_regola2_predef,$tipotariffa,$idinizioperiodo,$idfineperiodo,&$id_periodo_corrente,$tipo_periodi,$anno,$tableregole) {
+function dati_regole2 (&$dati_r2,&$app_regola2_predef,$tipotariffa,$inizioperiodo,$fineperiodo,&$id_periodo_corrente,$tipo_periodi,$anno,$tableregole) {
 
 if (!is_array($dati_r2)) {
 $dati_r2 = array('napp' => array());
@@ -141,12 +141,26 @@ $lista_app = "";
 if ($tipotariffa) {
 if (isset($dati_r2[$tipotariffa])) $lista_app = $dati_r2[$tipotariffa];
 if (isset($dati_r2['l2'][$tipotariffa]) and strcmp((string) $dati_r2['l2'][$tipotariffa],"")) {
+global $PHPR_TAB_PRE;
+$tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
 if (!$id_periodo_corrente) $id_periodo_corrente = calcola_id_periodo_corrente($anno);
 $ngiorni_reg2b = $dati_r2['dini'][$tipotariffa];
-if ($ngiorni_reg2b) $diff_giorni = $idinizioperiodo - $id_periodo_corrente + 1;
+if ($ngiorni_reg2b) {
+if (strstr($inizioperiodo,"-")) {
+$inizioperiodo = esegui_query("select idperiodi from $tableperiodi where datainizio = '".aggslashdb($inizioperiodo)."' ");
+if (numlin_query($inizioperiodo)) $inizioperiodo = risul_query($inizioperiodo,0,'idperiodi');
+else $inizioperiodo = 100000;
+} # fine if (strstr($inizioperiodo,"-"))
+$diff_giorni = $inizioperiodo - $id_periodo_corrente + 1;
+} # fine if ($ngiorni_reg2b)
 else {
+if (strstr($fineperiodo,"-")) {
+$fineperiodo = esegui_query("select idperiodi from $tableperiodi where datafine = '".aggslashdb($fineperiodo)."' ");
+if (numlin_query($fineperiodo)) $fineperiodo = risul_query($fineperiodo,0,'idperiodi');
+else $fineperiodo = 100000;
+} # fine if (strstr($fineperiodo,"-"))
 $ngiorni_reg2b = $dati_r2['dfine'][$tipotariffa];
-$diff_giorni = $idfineperiodo - $id_periodo_corrente + 1;
+$diff_giorni = $fineperiodo - $id_periodo_corrente + 1;
 } # fine else if ($ngiorni_reg2b)
 if ($tipo_periodi == "s") $diff_giorni = $diff_giorni * 7;
 if ($diff_giorni < $ngiorni_reg2b) {
@@ -355,7 +369,7 @@ if ($tipo_percent == "p") $perc = (round(($perc / $importa_arrotond),0) * $impor
 $prezzo_a = $prezzo_a + $perc;
 } # fine if ($perc)
 } # fine if ($dati_tariffe[$tariffa]['parte_prezzo'][$num_ord] != "p")
-if ($prezzo_a) esegui_query("update $tableperiodi set $tariffa = '$prezzo_a' where idperiodi = '$num1'");
+if (($prezzo_a and strcmp((string) $prezzoperiodo,"")) or ((string) $prezzo_a == "0" and (string) $prezzoperiodo == "0")) esegui_query("update $tableperiodi set $tariffa = '$prezzo_a' where idperiodi = '$num1'");
 else esegui_query("update $tableperiodi set $tariffa = NULL where idperiodi = '$num1'");
 } # fine if ((string) $prezzoperiodo != "NO")
 
@@ -374,7 +388,7 @@ if ($tipo_percent == "p") $perc = (round(($perc / $importa_arrotond),0) * $impor
 $prezzo_a_p = $prezzo_a_p + $perc;
 } # fine if ($perc)
 } # fine if ($dati_tariffe[$tariffa]['parte_prezzo'][$num_ord] != "f")
-if ($prezzo_a_p) esegui_query("update $tableperiodi set $tariffa"."p = '$prezzo_a_p' where idperiodi = '$num1'");
+if (($prezzo_a_p and strcmp((string) $prezzoperiodop,"")) or ((string) $prezzo_a_p == "0" and (string) $prezzoperiodop == "0")) esegui_query("update $tableperiodi set $tariffa"."p = '$prezzo_a_p' where idperiodi = '$num1'");
 else esegui_query("update $tableperiodi set $tariffa"."p = NULL where idperiodi = '$num1'");
 } # fine if ((string) $prezzoperiodop != "NO")
 
@@ -398,7 +412,7 @@ for ($num1 = 1 ; $num1 < $dati_tariffe[$tariffa]['num_per_importa'] ; $num1++) {
 if ($dati_tariffe[$tariffa]['periodo_importa_f'][$num1] >= $idperiodo and $dati_tariffe[$tariffa]['periodo_importa_i'][$num1] <= $idperiodo) {
 $imp_periodo = $dati_tariffe[$tariffa]['importa_prezzi'][$num1];
 break;
-} # fine if ($dati_tariffe[$tariffa]['periodo_importa_f'][$num1] >= $idinizioperiodo and...
+} # fine if ($dati_tariffe[$tariffa]['periodo_importa_f'][$num1] >= $idperiodo and...
 } # fine for $num1
 } # fine if ($dati_tariffe[$tariffa]['imp_prezzi_int'])
 return $imp_periodo;
