@@ -255,6 +255,9 @@ case "il prezzo della tariffa per le prime":  	$messaggio = "the rate price for
 case "della":  					$messaggio = "of the"; break;
 case "tariffa + sconto":  			$messaggio = "rate + discount"; break;
 case "tariffa + sconto + costi agg.":  		$messaggio = "rate + discount + extra costs"; break;
+case "della tar.":  				$messaggio = "of rate"; break;
+case "di t.+s.":  				$messaggio = "of r.+d."; break;
+case "di t.+s.+c.a.":  				$messaggio = "of r.+d.+e.c."; break;
 case "Nome della":  				$messaggio = "Name of"; break;
 case "Cambia":  				$messaggio = "Change"; break;
 case "prezzo per settimana":  			$messaggio = "price per week"; break;
@@ -321,6 +324,8 @@ case "questi tipi":  				$messaggio = "these types"; break;
 case "Mostrare come tipo di persona":  		$messaggio = "Display as person type"; break;
 case "Applicare la percentuale del tipo di persona al prezzo del costo":	$messaggio = "Apply the percentage of the person type to the price of the cost"; break;
 case "Neonati (0-23 mesi)":  			$messaggio = "Infants (0-23 months)"; break;
+case "tariffe con":  				$messaggio = "rates with"; break;
+case "a":  					$messaggio = "to"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
