@@ -125,6 +125,18 @@ case "Condizioni eliminate":  			$messaggio = "Deleted conditions"; break;
 case "tutti i documenti":  			$messaggio = "all documents"; break;
 case "documento":  				$messaggio = "document"; break;
 case "anche condizioni":  			$messaggio = "also conditions"; break;
+case "codif. in base64":  			$messaggio = "encoded to base64"; break;
+case "decodif. da base64":  			$messaggio = "dec. from base64"; break;
+case "codif. in HTML":  			$messaggio = "encoded to HTML"; break;
+case "decodif. da HTML":  			$messaggio = "dec. from HTML"; break;
+case "da base":  				$messaggio = "from base"; break;
+case "a":  					$messaggio = "to"; break;
+case "codificato in MIME base64":  		$messaggio = "encoded to MIME base64"; break;
+case "decodificato da MIME base64":  		$messaggio = "decoded from MIME base64"; break;
+case "codificato in HTML":  			$messaggio = "encoded to HTML"; break;
+case "decodificato da HTML":  			$messaggio = "decoded from HTML"; break;
+case "convertito da base":  			$messaggio = "converted from base"; break;
+case "a base":  				$messaggio = "to base"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
