@@ -36,6 +36,7 @@ $trad_var['email2'] = 'email2';
 $trad_var['email_certificata'] = 'certified_email';
 $trad_var['codice_fiscale'] = 'fiscal_code';
 $trad_var['partita_iva'] = 'vat_number';
+$trad_var['numero_cliente'] = 'client_number';
 $trad_var['num_persone'] = 'people_num';
 $trad_var['n_letti_agg'] = 'extra_beds_num';
 $trad_var['num_persone_tot'] = 'people_num_tot';
@@ -70,6 +71,7 @@ $trad_var['promemoria_uscita'] = 'checkout_reminder';
 $trad_var['origine_prenotazione'] = 'reservation_origin';
 $trad_var['unita_occupata'] = 'occupied_unit';
 $trad_var['unita_assegnabili'] = 'units_list';
+$trad_var['conferma'] = 'confirmation';
 $trad_var['pagato'] = 'paid';
 $trad_var['pagato_p'] = 'paid_p';
 $trad_var['resto_da_pagare'] = 'rest_to_pay';
@@ -129,8 +131,12 @@ $trad_var['tasso_cambio_pagamento'] = 'payment_exchange_rate';
 $trad_var['data_pagamento'] = 'payment_date';
 $trad_var['utente_pagamento'] = 'payment_user';
 $trad_var['metodo_pagamento'] = 'payment_method';
+$trad_var['id_pagamento'] = 'payment_id';
+$trad_var['note_pagamento'] = 'payment_notes';
+$trad_var['data_operazione_pagamento'] = 'payment_transaction_date';
 $trad_var['tutti_i_pagamenti'] = 'all_payments';
 $trad_var['tutti_i_pagamenti_p'] = 'all_payments_p';
+$trad_var['ultimo_pagamento'] = 'last_payment';
 $trad_var['valore_ultimo_pagamento'] = 'last_payment_value';
 $trad_var['valore_ultimo_pagamento_p'] = 'last_payment_value_p';
 $trad_var['data_ultimo_pagamento'] = 'last_payment_date';
@@ -140,6 +146,7 @@ $trad_var['num_pagamenti'] = 'payments_number';
 $trad_var['numero_prenotazione'] = 'reservation_number';
 $trad_var['numero_ripetizione_prenotazioni'] = 'reservations_repetition_number';
 $trad_var['codice_prenotazione'] = 'reservation_code';
+$trad_var['ultima_prenotazione_per_cliente'] = 'last_reservation_for_client';
 $trad_var['data_inserimento_prenotazione'] = 'reservation_insertion_date';
 $trad_var['utente_inserimento_prenotazione'] = 'reservation_insertion_user';
 $trad_var['numero_progressivo_documento'] = 'document_progressive_number';
@@ -180,6 +187,7 @@ $trad_var['codice3_regione_documento'] = 'document_region_code3';
 $trad_var['codice3_nazione_documento'] = 'document_nation_code3';
 $trad_var['num_ospiti_tot'] = 'guests_tot_num';
 $trad_var['numero_ospite'] = 'number_guest';
+$trad_var['numero_cliente_ospite'] = 'client_number_guest';
 $trad_var['cognome_ospite'] = 'surname_guest';
 $trad_var['nome_ospite'] = 'name_guest';
 $trad_var['soprannome_ospite'] = 'nickname_guest';
@@ -312,6 +320,9 @@ $trad_var['nome_documento_salvato'] = 'saved_document_name';
 $trad_var['numero_progressivo_documento_salvato'] = 'saved_document_progressive_number';
 $trad_var['data_creazione_documento_salvato'] = 'saved_document_creation_date';
 $trad_var['nome_file_documento_salvato'] = 'saved_document_filename';
+$trad_var['nome_download_documento_salvato'] = 'saved_document_download_name';
+$trad_var['nome_documento_scaricato'] = 'downloaded_document_name';
+$trad_var['allegato'] = 'attachment';
 
 
 ?>
\ No newline at end of file
