@@ -136,7 +136,7 @@ case "Non_mostrare":  				$messaggio = "Do_not_display"; break;
 case "Regole":  				$messaggio = "Rules"; break;
 case "Tariffe abbinate":  			$messaggio = "Associated rates"; break;
 case "pagine":  				$messaggio = "pages"; break;
-case "Verranno effettuati i seguenti cambiamenti":	$messaggio = "You will make this changes"; break;
+case "Verranno effettuati i seguenti cambiamenti":	$messaggio = "You will make these changes"; break;
 case "I soldi pagati per la prenotazione":  	$messaggio = "Money paid for reservation"; break;
 case "a nome di":  				$messaggio = "for Mr/Mrs"; break;
 case "verranno cambiati da":  			$messaggio = "will be changed from"; break;
@@ -374,6 +374,9 @@ case "escludendo":  				$messaggio = "excluding"; break;
 case "includendo solo":  			$messaggio = "including only"; break;
 case "e":  					$messaggio = "and"; break;
 case "Superato il massimo numero di anni comparabili":	$messaggio = "Exceeded the maximum number of comparable years"; break;
+case "Numero_predefinito di persone":  		$messaggio = "Default_number of people"; break;
+case "Numero_minimo di persone":  		$messaggio = "Minimum_number of people"; break;
+case "Id":  					$messaggio = "Id"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
