@@ -255,6 +255,9 @@ case "il prezzo della tariffa per le prime":  	$messaggio = "el precio de la tar
 case "della":  					$messaggio = "de la"; break;
 case "tariffa + sconto":  			$messaggio = "tarifa + descuento"; break;
 case "tariffa + sconto + costi agg.":  		$messaggio = "tarifa + descuento + costes añad."; break;
+case "della tar.":  				$messaggio = "de la tar."; break;
+case "di t.+s.":  				$messaggio = "de t.+d."; break;
+case "di t.+s.+c.a.":  				$messaggio = "de t.+d.+c.a."; break;
 case "Nome della":  				$messaggio = "Nombre de la"; break;
 case "Cambia":  				$messaggio = "Cambiar"; break;
 case "prezzo per settimana":  			$messaggio = "precio por semana"; break;
@@ -321,6 +324,9 @@ case "questi tipi":  				$messaggio = "estos tipos"; break;
 case "Mostrare come tipo di persona":  		$messaggio = "Enseñar como tipo de persona"; break;
 case "Applicare la percentuale del tipo di persona al prezzo del costo":	$messaggio = "Aplicar el porcentaje del tipo de persona al coste"; break;
 case "Neonati (0-23 mesi)":  				$messaggio = "Bebés (0-23 meses)"; break;
+case "tariffe con":  				$messaggio = "tarifas con"; break;
+case "a":  					$messaggio = "a"; break;
+case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
