@@ -125,6 +125,18 @@ case "Condizioni eliminate":  			$messaggio = "Condiciones eliminadas"; break;
 case "tutti i documenti":  			$messaggio = "todos los documentos"; break;
 case "documento":  				$messaggio = "documento"; break;
 case "anche condizioni":  			$messaggio = "también condiciones"; break;
+case "codif. in base64":  			$messaggio = "codif. a base64"; break;
+case "decodif. da base64":  			$messaggio = "decod. desde base64"; break;
+case "codif. in HTML":  			$messaggio = "codif. a HTML"; break;
+case "decodif. da HTML":  			$messaggio = "decod. desde HTML"; break;
+case "da base":  				$messaggio = "desde base"; break;
+case "a":  					$messaggio = "a"; break;
+case "codificato in MIME base64":  		$messaggio = "codificado a base64"; break;
+case "decodificato da MIME base64":  		$messaggio = "decodificado desde MIME base64"; break;
+case "codificato in HTML":  			$messaggio = "codificado a HTML"; break;
+case "decodificato da HTML":  			$messaggio = "decodificado desde HTML"; break;
+case "convertito da base":  			$messaggio = "convertido desde base"; break;
+case "a base":  				$messaggio = "a base"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
