@@ -269,7 +269,7 @@ case "CAP":  					$messaggio = "Código postal"; break;
 case "Telefono":  				$messaggio = "Teléfono"; break;
 case "Fax":  					$messaggio = "Fax"; break;
 case "Codice fiscale":  			$messaggio = "Número Identificación Fiscal"; break;
-case "Parita iva":  				$messaggio = "Cert. Identificación Fiscal"; break;
+case "Partita iva":  				$messaggio = "Certificado Identif. Fiscal"; break;
 case "Modifica i dati della struttura":  	$messaggio = "Modificar los datos de la propiedad"; break;
 case "Clicca su un documento per modificarlo":	$messaggio = "Hacer clic sobre un documento para modificarlo"; break;
 case "Cambia l'ordine dei documenti":  		$messaggio = "Cambiar el orden de los documentos"; break;
@@ -471,6 +471,7 @@ case "nella gestione del suo DNS va aggiunto un record TXT contenente un testo c
 case "Questo è il record SPF attuale del dominio":	$messaggio = "Este es el record SPF actual del dominio"; break;
 case "questo record TXT va modificato nella gestione del DNS del dominio":	$messaggio = "este record TXT debe ser modificado en la gestión del DNS del dominio"; break;
 case "sostituendolo con un testo come questo":	$messaggio = "reemplazándolo con un texto como este"; break;
+case "Dopo la modifica potrebbero volerci alcune ore affinchè l'aggiornamento sia attivo":	$messaggio = "Después del cambio, la actualización puede tardar algunas horas en tener efecto."; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
