@@ -9,442 +9,442 @@ $cod_nazione_regioni = array();
 $lista_regioni[0] = "Agrigento";
 $cod_regioni[0] = "AG";
 $cod2_regioni[0] = "084";
-$cod_nazione_regioni[0] = "100000100";
+$cod_nazione_regioni[0] = "IT";
 $lista_regioni[1] = "Alessandria";
 $cod_regioni[1] = "AL";
 $cod2_regioni[1] = "006";
-$cod_nazione_regioni[1] = "100000100";
+$cod_nazione_regioni[1] = "IT";
 $lista_regioni[2] = "Ancona";
 $cod_regioni[2] = "AN";
 $cod2_regioni[2] = "042";
-$cod_nazione_regioni[2] = "100000100";
+$cod_nazione_regioni[2] = "IT";
 $lista_regioni[3] = "Aosta";
 $cod_regioni[3] = "AO";
 $cod2_regioni[3] = "007";
-$cod_nazione_regioni[3] = "100000100";
+$cod_nazione_regioni[3] = "IT";
 $lista_regioni[4] = "Arezzo";
 $cod_regioni[4] = "AR";
 $cod2_regioni[4] = "051";
-$cod_nazione_regioni[4] = "100000100";
+$cod_nazione_regioni[4] = "IT";
 $lista_regioni[5] = "Ascoli Piceno";
 $cod_regioni[5] = "AP";
 $cod2_regioni[5] = "044";
-$cod_nazione_regioni[5] = "100000100";
+$cod_nazione_regioni[5] = "IT";
 $lista_regioni[6] = "Asti";
 $cod_regioni[6] = "AT";
 $cod2_regioni[6] = "005";
-$cod_nazione_regioni[6] = "100000100";
+$cod_nazione_regioni[6] = "IT";
 $lista_regioni[7] = "Avellino";
 $cod_regioni[7] = "AV";
 $cod2_regioni[7] = "064";
-$cod_nazione_regioni[7] = "100000100";
+$cod_nazione_regioni[7] = "IT";
 $lista_regioni[8] = "Bari";
 $cod_regioni[8] = "BA";
 $cod2_regioni[8] = "072";
-$cod_nazione_regioni[8] = "100000100";
+$cod_nazione_regioni[8] = "IT";
 $lista_regioni[9] = "Barletta-Andria-Trani";
 $cod_regioni[9] = "BT";
 $cod2_regioni[9] = "110";
-$cod_nazione_regioni[9] = "100000100";
+$cod_nazione_regioni[9] = "IT";
 $lista_regioni[10] = "Belluno";
 $cod_regioni[10] = "BL";
 $cod2_regioni[10] = "025";
-$cod_nazione_regioni[10] = "100000100";
+$cod_nazione_regioni[10] = "IT";
 $lista_regioni[11] = "Benevento";
 $cod_regioni[11] = "BN";
 $cod2_regioni[11] = "062";
-$cod_nazione_regioni[11] = "100000100";
+$cod_nazione_regioni[11] = "IT";
 $lista_regioni[12] = "Bergamo";
 $cod_regioni[12] = "BG";
 $cod2_regioni[12] = "016";
-$cod_nazione_regioni[12] = "100000100";
+$cod_nazione_regioni[12] = "IT";
 $lista_regioni[13] = "Biella";
 $cod_regioni[13] = "BI";
 $cod2_regioni[13] = "096";
-$cod_nazione_regioni[13] = "100000100";
+$cod_nazione_regioni[13] = "IT";
 $lista_regioni[14] = "Bologna";
 $cod_regioni[14] = "BO";
 $cod2_regioni[14] = "037";
-$cod_nazione_regioni[14] = "100000100";
+$cod_nazione_regioni[14] = "IT";
 $lista_regioni[15] = "Bolzano (Bozen)";
 $cod_regioni[15] = "BZ";
 $cod2_regioni[15] = "021";
-$cod_nazione_regioni[15] = "100000100";
+$cod_nazione_regioni[15] = "IT";
 $lista_regioni[16] = "Brescia";
 $cod_regioni[16] = "BS";
 $cod2_regioni[16] = "017";
-$cod_nazione_regioni[16] = "100000100";
+$cod_nazione_regioni[16] = "IT";
 $lista_regioni[17] = "Brindisi";
 $cod_regioni[17] = "BR";
 $cod2_regioni[17] = "074";
-$cod_nazione_regioni[17] = "100000100";
+$cod_nazione_regioni[17] = "IT";
 $lista_regioni[18] = "Cagliari";
 $cod_regioni[18] = "CA";
 $cod2_regioni[18] = "092";
-$cod_nazione_regioni[18] = "100000100";
+$cod_nazione_regioni[18] = "IT";
 $lista_regioni[19] = "Caltanissetta";
 $cod_regioni[19] = "CL";
 $cod2_regioni[19] = "085";
-$cod_nazione_regioni[19] = "100000100";
+$cod_nazione_regioni[19] = "IT";
 $lista_regioni[20] = "Campobasso";
 $cod_regioni[20] = "CB";
 $cod2_regioni[20] = "070";
-$cod_nazione_regioni[20] = "100000100";
+$cod_nazione_regioni[20] = "IT";
 $lista_regioni[21] = "Carbonia-Iglesias";
 $cod_regioni[21] = "CI";
 $cod2_regioni[21] = "107";
-$cod_nazione_regioni[21] = "100000100";
+$cod_nazione_regioni[21] = "IT";
 $lista_regioni[22] = "Caserta";
 $cod_regioni[22] = "CE";
 $cod2_regioni[22] = "061";
-$cod_nazione_regioni[22] = "100000100";
+$cod_nazione_regioni[22] = "IT";
 $lista_regioni[23] = "Catania";
 $cod_regioni[23] = "CT";
 $cod2_regioni[23] = "087";
-$cod_nazione_regioni[23] = "100000100";
+$cod_nazione_regioni[23] = "IT";
 $lista_regioni[24] = "Catanzaro";
 $cod_regioni[24] = "CZ";
 $cod2_regioni[24] = "079";
-$cod_nazione_regioni[24] = "100000100";
+$cod_nazione_regioni[24] = "IT";
 $lista_regioni[25] = "Chieti";
 $cod_regioni[25] = "CH";
 $cod2_regioni[25] = "069";
-$cod_nazione_regioni[25] = "100000100";
+$cod_nazione_regioni[25] = "IT";
 $lista_regioni[26] = "Como";
 $cod_regioni[26] = "CO";
 $cod2_regioni[26] = "013";
-$cod_nazione_regioni[26] = "100000100";
+$cod_nazione_regioni[26] = "IT";
 $lista_regioni[27] = "Cosenza";
 $cod_regioni[27] = "CS";
 $cod2_regioni[27] = "078";
-$cod_nazione_regioni[27] = "100000100";
+$cod_nazione_regioni[27] = "IT";
 $lista_regioni[28] = "Cremona";
 $cod_regioni[28] = "CR";
 $cod2_regioni[28] = "019";
-$cod_nazione_regioni[28] = "100000100";
+$cod_nazione_regioni[28] = "IT";
 $lista_regioni[29] = "Crotone";
 $cod_regioni[29] = "KR";
 $cod2_regioni[29] = "101";
-$cod_nazione_regioni[29] = "100000100";
+$cod_nazione_regioni[29] = "IT";
 $lista_regioni[30] = "Cuneo";
 $cod_regioni[30] = "CN";
 $cod2_regioni[30] = "004";
-$cod_nazione_regioni[30] = "100000100";
+$cod_nazione_regioni[30] = "IT";
 $lista_regioni[31] = "Enna";
 $cod_regioni[31] = "EN";
 $cod2_regioni[31] = "086";
-$cod_nazione_regioni[31] = "100000100";
+$cod_nazione_regioni[31] = "IT";
 $lista_regioni[32] = "Fermo";
 $cod_regioni[32] = "FM";
 $cod2_regioni[32] = "109";
-$cod_nazione_regioni[32] = "100000100";
+$cod_nazione_regioni[32] = "IT";
 $lista_regioni[33] = "Ferrara";
 $cod_regioni[33] = "FE";
 $cod2_regioni[33] = "038";
-$cod_nazione_regioni[33] = "100000100";
+$cod_nazione_regioni[33] = "IT";
 $lista_regioni[34] = "Firenze";
 $cod_regioni[34] = "FI";
 $cod2_regioni[34] = "048";
-$cod_nazione_regioni[34] = "100000100";
+$cod_nazione_regioni[34] = "IT";
 $lista_regioni[35] = "Foggia";
 $cod_regioni[35] = "FG";
 $cod2_regioni[35] = "071";
-$cod_nazione_regioni[35] = "100000100";
+$cod_nazione_regioni[35] = "IT";
 $lista_regioni[36] = "Forli-Cesena";
 $cod_regioni[36] = "FC";
 $cod2_regioni[36] = "040";
-$cod_nazione_regioni[36] = "100000100";
+$cod_nazione_regioni[36] = "IT";
 $lista_regioni[37] = "Frosinone";
 $cod_regioni[37] = "FR";
 $cod2_regioni[37] = "060";
-$cod_nazione_regioni[37] = "100000100";
+$cod_nazione_regioni[37] = "IT";
 $lista_regioni[38] = "Genova";
 $cod_regioni[38] = "GE";
 $cod2_regioni[38] = "010";
-$cod_nazione_regioni[38] = "100000100";
+$cod_nazione_regioni[38] = "IT";
 $lista_regioni[39] = "Gorizia";
 $cod_regioni[39] = "GO";
 $cod2_regioni[39] = "031";
-$cod_nazione_regioni[39] = "100000100";
+$cod_nazione_regioni[39] = "IT";
 $lista_regioni[40] = "Grosseto";
 $cod_regioni[40] = "GR";
 $cod2_regioni[40] = "053";
-$cod_nazione_regioni[40] = "100000100";
+$cod_nazione_regioni[40] = "IT";
 $lista_regioni[41] = "Imperia";
 $cod_regioni[41] = "IM";
 $cod2_regioni[41] = "008";
-$cod_nazione_regioni[41] = "100000100";
+$cod_nazione_regioni[41] = "IT";
 $lista_regioni[42] = "Isernia";
 $cod_regioni[42] = "IS";
 $cod2_regioni[42] = "094";
-$cod_nazione_regioni[42] = "100000100";
+$cod_nazione_regioni[42] = "IT";
 $lista_regioni[43] = "La Spezia";
 $cod_regioni[43] = "SP";
 $cod2_regioni[43] = "011";
-$cod_nazione_regioni[43] = "100000100";
+$cod_nazione_regioni[43] = "IT";
 $lista_regioni[44] = "L'Aquila";
 $cod_regioni[44] = "AQ";
 $cod2_regioni[44] = "066";
-$cod_nazione_regioni[44] = "100000100";
+$cod_nazione_regioni[44] = "IT";
 $lista_regioni[45] = "Latina";
 $cod_regioni[45] = "LT";
 $cod2_regioni[45] = "059";
-$cod_nazione_regioni[45] = "100000100";
+$cod_nazione_regioni[45] = "IT";
 $lista_regioni[46] = "Lecce";
 $cod_regioni[46] = "LE";
 $cod2_regioni[46] = "075";
-$cod_nazione_regioni[46] = "100000100";
+$cod_nazione_regioni[46] = "IT";
 $lista_regioni[47] = "Lecco";
 $cod_regioni[47] = "LC";
 $cod2_regioni[47] = "097";
-$cod_nazione_regioni[47] = "100000100";
+$cod_nazione_regioni[47] = "IT";
 $lista_regioni[48] = "Livorno";
 $cod_regioni[48] = "LI";
 $cod2_regioni[48] = "049";
-$cod_nazione_regioni[48] = "100000100";
+$cod_nazione_regioni[48] = "IT";
 $lista_regioni[49] = "Lodi";
 $cod_regioni[49] = "LO";
 $cod2_regioni[49] = "098";
-$cod_nazione_regioni[49] = "100000100";
+$cod_nazione_regioni[49] = "IT";
 $lista_regioni[50] = "Lucca";
 $cod_regioni[50] = "LU";
 $cod2_regioni[50] = "046";
-$cod_nazione_regioni[50] = "100000100";
+$cod_nazione_regioni[50] = "IT";
 $lista_regioni[51] = "Macerata";
 $cod_regioni[51] = "MC";
 $cod2_regioni[51] = "043";
-$cod_nazione_regioni[51] = "100000100";
+$cod_nazione_regioni[51] = "IT";
 $lista_regioni[52] = "Mantova";
 $cod_regioni[52] = "MN";
 $cod2_regioni[52] = "020";
-$cod_nazione_regioni[52] = "100000100";
+$cod_nazione_regioni[52] = "IT";
 $lista_regioni[53] = "Massa-Carrara";
 $cod_regioni[53] = "MS";
 $cod2_regioni[53] = "045";
-$cod_nazione_regioni[53] = "100000100";
+$cod_nazione_regioni[53] = "IT";
 $lista_regioni[54] = "Matera";
 $cod_regioni[54] = "MT";
 $cod2_regioni[54] = "077";
-$cod_nazione_regioni[54] = "100000100";
+$cod_nazione_regioni[54] = "IT";
 $lista_regioni[55] = "Medio Campidano";
 $cod_regioni[55] = "VS";
 $cod2_regioni[55] = "106";
-$cod_nazione_regioni[55] = "100000100";
+$cod_nazione_regioni[55] = "IT";
 $lista_regioni[56] = "Messina";
 $cod_regioni[56] = "ME";
 $cod2_regioni[56] = "083";
-$cod_nazione_regioni[56] = "100000100";
+$cod_nazione_regioni[56] = "IT";
 $lista_regioni[57] = "Milano";
 $cod_regioni[57] = "MI";
 $cod2_regioni[57] = "015";
-$cod_nazione_regioni[57] = "100000100";
+$cod_nazione_regioni[57] = "IT";
 $lista_regioni[58] = "Modena";
 $cod_regioni[58] = "MO";
 $cod2_regioni[58] = "036";
-$cod_nazione_regioni[58] = "100000100";
+$cod_nazione_regioni[58] = "IT";
 $lista_regioni[59] = "Monza e Brianza";
 $cod_regioni[59] = "MB";
 $cod2_regioni[59] = "108";
-$cod_nazione_regioni[59] = "100000100";
+$cod_nazione_regioni[59] = "IT";
 $lista_regioni[60] = "Napoli";
 $cod_regioni[60] = "NA";
 $cod2_regioni[60] = "063";
-$cod_nazione_regioni[60] = "100000100";
+$cod_nazione_regioni[60] = "IT";
 $lista_regioni[61] = "Novara";
 $cod_regioni[61] = "NO";
 $cod2_regioni[61] = "003";
-$cod_nazione_regioni[61] = "100000100";
+$cod_nazione_regioni[61] = "IT";
 $lista_regioni[62] = "Nuoro";
 $cod_regioni[62] = "NU";
 $cod2_regioni[62] = "091";
-$cod_nazione_regioni[62] = "100000100";
+$cod_nazione_regioni[62] = "IT";
 $lista_regioni[63] = "Ogliastra";
 $cod_regioni[63] = "OG";
 $cod2_regioni[63] = "105";
-$cod_nazione_regioni[63] = "100000100";
+$cod_nazione_regioni[63] = "IT";
 $lista_regioni[64] = "Olbia-Tempio";
 $cod_regioni[64] = "OT";
 $cod2_regioni[64] = "104";
-$cod_nazione_regioni[64] = "100000100";
+$cod_nazione_regioni[64] = "IT";
 $lista_regioni[65] = "Oristano";
 $cod_regioni[65] = "OR";
 $cod2_regioni[65] = "095";
-$cod_nazione_regioni[65] = "100000100";
+$cod_nazione_regioni[65] = "IT";
 $lista_regioni[66] = "Padova";
 $cod_regioni[66] = "PD";
 $cod2_regioni[66] = "028";
-$cod_nazione_regioni[66] = "100000100";
+$cod_nazione_regioni[66] = "IT";
 $lista_regioni[67] = "Palermo";
 $cod_regioni[67] = "PA";
 $cod2_regioni[67] = "082";
-$cod_nazione_regioni[67] = "100000100";
+$cod_nazione_regioni[67] = "IT";
 $lista_regioni[68] = "Parma";
 $cod_regioni[68] = "PR";
 $cod2_regioni[68] = "034";
-$cod_nazione_regioni[68] = "100000100";
+$cod_nazione_regioni[68] = "IT";
 $lista_regioni[69] = "Pavia";
 $cod_regioni[69] = "PV";
 $cod2_regioni[69] = "018";
-$cod_nazione_regioni[69] = "100000100";
+$cod_nazione_regioni[69] = "IT";
 $lista_regioni[70] = "Perugia";
 $cod_regioni[70] = "PG";
 $cod2_regioni[70] = "054";
-$cod_nazione_regioni[70] = "100000100";
+$cod_nazione_regioni[70] = "IT";
 $lista_regioni[71] = "Pesaro E Urbino";
 $cod_regioni[71] = "PS";
 $cod2_regioni[71] = "041";
-$cod_nazione_regioni[71] = "100000100";
+$cod_nazione_regioni[71] = "IT";
 $lista_regioni[72] = "Pescara";
 $cod_regioni[72] = "PE";
 $cod2_regioni[72] = "068";
-$cod_nazione_regioni[72] = "100000100";
+$cod_nazione_regioni[72] = "IT";
 $lista_regioni[73] = "Piacenza";
 $cod_regioni[73] = "PC";
 $cod2_regioni[73] = "033";
-$cod_nazione_regioni[73] = "100000100";
+$cod_nazione_regioni[73] = "IT";
 $lista_regioni[74] = "Pisa";
 $cod_regioni[74] = "PI";
 $cod2_regioni[74] = "050";
-$cod_nazione_regioni[74] = "100000100";
+$cod_nazione_regioni[74] = "IT";
 $lista_regioni[75] = "Pistoia";
 $cod_regioni[75] = "PT";
 $cod2_regioni[75] = "047";
-$cod_nazione_regioni[75] = "100000100";
+$cod_nazione_regioni[75] = "IT";
 $lista_regioni[76] = "Pordenone";
 $cod_regioni[76] = "PN";
 $cod2_regioni[76] = "093";
-$cod_nazione_regioni[76] = "100000100";
+$cod_nazione_regioni[76] = "IT";
 $lista_regioni[77] = "Potenza";
 $cod_regioni[77] = "PZ";
 $cod2_regioni[77] = "076";
-$cod_nazione_regioni[77] = "100000100";
+$cod_nazione_regioni[77] = "IT";
 $lista_regioni[78] = "Prato";
 $cod_regioni[78] = "PO";
 $cod2_regioni[78] = "100";
-$cod_nazione_regioni[78] = "100000100";
+$cod_nazione_regioni[78] = "IT";
 $lista_regioni[79] = "Ragusa";
 $cod_regioni[79] = "RG";
 $cod2_regioni[79] = "088";
-$cod_nazione_regioni[79] = "100000100";
+$cod_nazione_regioni[79] = "IT";
 $lista_regioni[80] = "Ravenna";
 $cod_regioni[80] = "RA";
 $cod2_regioni[80] = "039";
-$cod_nazione_regioni[80] = "100000100";
+$cod_nazione_regioni[80] = "IT";
 $lista_regioni[81] = "Reggio Calabria";
 $cod_regioni[81] = "RC";
 $cod2_regioni[81] = "080";
-$cod_nazione_regioni[81] = "100000100";
+$cod_nazione_regioni[81] = "IT";
 $lista_regioni[82] = "Reggio Nell'Emilia";
 $cod_regioni[82] = "RE";
 $cod2_regioni[82] = "035";
-$cod_nazione_regioni[82] = "100000100";
+$cod_nazione_regioni[82] = "IT";
 $lista_regioni[83] = "Rieti";
 $cod_regioni[83] = "RI";
 $cod2_regioni[83] = "057";
-$cod_nazione_regioni[83] = "100000100";
+$cod_nazione_regioni[83] = "IT";
 $lista_regioni[84] = "Rimini";
 $cod_regioni[84] = "RN";
 $cod2_regioni[84] = "099";
-$cod_nazione_regioni[84] = "100000100";
+$cod_nazione_regioni[84] = "IT";
 $lista_regioni[85] = "Roma";
 $cod_regioni[85] = "RM";
 $cod2_regioni[85] = "058";
-$cod_nazione_regioni[85] = "100000100";
+$cod_nazione_regioni[85] = "IT";
 $lista_regioni[86] = "Rovigo";
 $cod_regioni[86] = "RO";
 $cod2_regioni[86] = "029";
-$cod_nazione_regioni[86] = "100000100";
+$cod_nazione_regioni[86] = "IT";
 $lista_regioni[87] = "Salerno";
 $cod_regioni[87] = "SA";
 $cod2_regioni[87] = "065";
-$cod_nazione_regioni[87] = "100000100";
+$cod_nazione_regioni[87] = "IT";
 $lista_regioni[88] = "Sassari";
 $cod_regioni[88] = "SS";
 $cod2_regioni[88] = "090";
-$cod_nazione_regioni[88] = "100000100";
+$cod_nazione_regioni[88] = "IT";
 $lista_regioni[89] = "Savona";
 $cod_regioni[89] = "SV";
 $cod2_regioni[89] = "009";
-$cod_nazione_regioni[89] = "100000100";
+$cod_nazione_regioni[89] = "IT";
 $lista_regioni[90] = "Siena";
 $cod_regioni[90] = "SI";
 $cod2_regioni[90] = "052";
-$cod_nazione_regioni[90] = "100000100";
+$cod_nazione_regioni[90] = "IT";
 $lista_regioni[91] = "Siracusa";
 $cod_regioni[91] = "SR";
 $cod2_regioni[91] = "089";
-$cod_nazione_regioni[91] = "100000100";
+$cod_nazione_regioni[91] = "IT";
 $lista_regioni[92] = "Sondrio";
 $cod_regioni[92] = "SO";
 $cod2_regioni[92] = "014";
-$cod_nazione_regioni[92] = "100000100";
+$cod_nazione_regioni[92] = "IT";
 $lista_regioni[93] = "Taranto";
 $cod_regioni[93] = "TA";
 $cod2_regioni[93] = "073";
-$cod_nazione_regioni[93] = "100000100";
+$cod_nazione_regioni[93] = "IT";
 $lista_regioni[94] = "Teramo";
 $cod_regioni[94] = "TE";
 $cod2_regioni[94] = "067";
-$cod_nazione_regioni[94] = "100000100";
+$cod_nazione_regioni[94] = "IT";
 $lista_regioni[95] = "Terni";
 $cod_regioni[95] = "TR";
 $cod2_regioni[95] = "055";
-$cod_nazione_regioni[95] = "100000100";
+$cod_nazione_regioni[95] = "IT";
 $lista_regioni[96] = "Torino";
 $cod_regioni[96] = "TO";
 $cod2_regioni[96] = "001";
-$cod_nazione_regioni[96] = "100000100";
+$cod_nazione_regioni[96] = "IT";
 $lista_regioni[97] = "Trapani";
 $cod_regioni[97] = "TP";
 $cod2_regioni[97] = "081";
-$cod_nazione_regioni[97] = "100000100";
+$cod_nazione_regioni[97] = "IT";
 $lista_regioni[98] = "Trento";
 $cod_regioni[98] = "TN";
 $cod2_regioni[98] = "022";
-$cod_nazione_regioni[98] = "100000100";
+$cod_nazione_regioni[98] = "IT";
 $lista_regioni[99] = "Treviso";
 $cod_regioni[99] = "TV";
 $cod2_regioni[99] = "026";
-$cod_nazione_regioni[99] = "100000100";
+$cod_nazione_regioni[99] = "IT";
 $lista_regioni[100] = "Trieste";
 $cod_regioni[100] = "TS";
 $cod2_regioni[100] = "032";
-$cod_nazione_regioni[100] = "100000100";
+$cod_nazione_regioni[100] = "IT";
 $lista_regioni[101] = "Udine";
 $cod_regioni[101] = "UD";
 $cod2_regioni[101] = "030";
-$cod_nazione_regioni[101] = "100000100";
+$cod_nazione_regioni[101] = "IT";
 $lista_regioni[102] = "Varese";
 $cod_regioni[102] = "VA";
 $cod2_regioni[102] = "012";
-$cod_nazione_regioni[102] = "100000100";
+$cod_nazione_regioni[102] = "IT";
 $lista_regioni[103] = "Venezia";
 $cod_regioni[103] = "VE";
 $cod2_regioni[103] = "027";
-$cod_nazione_regioni[103] = "100000100";
+$cod_nazione_regioni[103] = "IT";
 $lista_regioni[104] = "Verbano-Cusio-Ossola";
 $cod_regioni[104] = "VB";
 $cod2_regioni[104] = "103";
-$cod_nazione_regioni[104] = "100000100";
+$cod_nazione_regioni[104] = "IT";
 $lista_regioni[105] = "Vercelli";
 $cod_regioni[105] = "VC";
 $cod2_regioni[105] = "002";
-$cod_nazione_regioni[105] = "100000100";
+$cod_nazione_regioni[105] = "IT";
 $lista_regioni[106] = "Verona";
 $cod_regioni[106] = "VR";
 $cod2_regioni[106] = "023";
-$cod_nazione_regioni[106] = "100000100";
+$cod_nazione_regioni[106] = "IT";
 $lista_regioni[107] = "Vibo Valentia";
 $cod_regioni[107] = "VV";
 $cod2_regioni[107] = "102";
-$cod_nazione_regioni[107] = "100000100";
+$cod_nazione_regioni[107] = "IT";
 $lista_regioni[108] = "Vicenza";
 $cod_regioni[108] = "VI";
 $cod2_regioni[108] = "024";
-$cod_nazione_regioni[108] = "100000100";
+$cod_nazione_regioni[108] = "IT";
 $lista_regioni[109] = "Viterbo";
 $cod_regioni[109] = "VT";
 $cod2_regioni[109] = "056";
-$cod_nazione_regioni[109] = "100000100";
+$cod_nazione_regioni[109] = "IT";
 
 ?>
\ No newline at end of file
