@@ -46,7 +46,7 @@ if (@is_file("$percorso_cartella_modello/$nome_file")) {
 $modello_esistente = "SI";
 $lingua_mex = $lingua_mex_1;
 include("./includes/templates/$template_data_dir/functions.php");
-recupera_var_modello_cal($nome_file,$percorso_cartella_modello,$pag,$fr_frase,$num_frasi,$var_mod,$num_var_mod,$tipo_periodi,"NO",$anno_modello,$PHPR_TAB_PRE);
+recupera_var_modello_cal($nome_file,$percorso_cartella_modello,$pag,$fr_frase,$frase,$num_frasi,$var_mod,$num_var_mod,$tipo_periodi,"NO",$anno_modello,$lingua_modello,$PHPR_TAB_PRE);
 $lingua_mex = $lingua_orig;
 
 $tabelle_lock = array($tableversioni,$tabletransazioni);
@@ -207,7 +207,7 @@ $numero_tariffe = risul_query($rigatariffe,0,'nomecostoagg');
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
 if (isset($tariffe_mostra[$numtariffa]) and strtoupper($tariffe_mostra[$numtariffa]) == $SI) $checked = " checked";
 else $checked = "";
-if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI" or $checked) {
+if ($attiva_tariffe_consentite == "n" or (isset($tariffe_consentite_vett[$numtariffa]) and $tariffe_consentite_vett[$numtariffa] == "SI") or $checked) {
 if ($celle == 1) echo "<tr>";
 $tariffa = "tariffa".$numtariffa;
 $nometariffa=risul_query($rigatariffe,0,$tariffa);
@@ -227,7 +227,7 @@ echo "</tr>";
 $celle = 0;
 } # fine if ($celle == 3)
 $celle++;
-} # fine if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI" or $checked)
+} # fine if ($attiva_tariffe_consentite == "n" or (isset($tariffe_consentite_vett[$numtariffa]) and...
 } # fine for $numtariffa
 if ($celle != 1) {
 for ($num1 = $celle ; $num1 <= $num_colonne ; $num1++) echo "<td>&nbsp;</td>";
@@ -243,7 +243,7 @@ $num_colonne = 3;
 $tableregole_modello = $PHPR_TAB_PRE."regole".$anno_modello;
 $regole = esegui_query("select * from $tableregole_modello where app_agenzia != '' and (motivazione2 != 'x' or motivazione2 is NULL) order by app_agenzia");
 $num_regole = numlin_query($regole);
-unset($motivazioni_presenti);
+$motivazioni_presenti = array();
 $num_motivazioni = 0;
 for ($num1 = 0 ; $num1 < $num_regole ; $num1 = $num1 + 1) {
 $motivazione = risul_query($regole,$num1,'motivazione');
@@ -252,7 +252,7 @@ $motivazione = " ";
 $motivazione_vedi = mex("nessuna",$pag);
 } # fine if (!$motivazione)
 else $motivazione_vedi = $motivazione;
-if (strtoupper($considera_motivazioni_regola1[$motivazione]) == $SI) $checked = " checked";
+if (strtoupper(fixstr($considera_motivazioni_regola1[$motivazione])) == $SI) $checked = " checked";
 else $checked = "";
 $regola1_consentita = 0;
 if ($attiva_regole1_consentite == "n" or $checked) $regola1_consentita = 1;
@@ -260,11 +260,11 @@ else for ($num2 = 0 ; $num2 < count($regole1_consentite) ; $num2++) if ($regole1
 if ($regola1_consentita) {
 if ($celle == 1) echo "<tr>";
 $idregole = risul_query($regole,$num1,'idregole');
-if ($motivazioni_presenti[$motivazione] != "SI") {
-$motivazioni_presenti[$motivazione] = "SI";
+if (!isset($motivazioni_presenti[$motivazione])) {
+$motivazioni_presenti[$motivazione] = 1;
 $var_motivazione = "var_mot_".$num_motivazioni;
 $num_motivazioni++;
-if (!$considera_motivazioni_regola1['array_esistente']) $checked = " checked";
+if (empty($considera_motivazioni_regola1['array_esistente'])) $checked = " checked";
 echo "<td><label><input type=\"checkbox\" name=\"$var_motivazione\" value=\"$motivazione\"$checked> $motivazione_vedi</label></td>";
 if ($celle == $num_colonne) {
 echo "</tr>";
@@ -445,13 +445,13 @@ for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) echo "<input type=\"hidden\
 } # fine elseif ($modello_esistente == "SI")
 
 echo "<br><div style=\"text-align: center;\"><input type=\"hidden\" name=\"$template_name\" value=\"SI\">
-<button class=\"vmon\" type=\"submit\"><div>".mext_cal("Crea la pagina con il calendario della disponibilità",$pag)."</div></button>
+<button class=\"vmon\" id=\"modi\" type=\"submit\"><div>".mext_cal("Crea la pagina con il calendario della disponibilità",$pag)."</div></button>
 </div></div></form><br>
 <hr style=\"width: 95%\"><br><div style=\"text-align: center;\">
 <form method=\"post\" action=\"crea_modelli.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
+<button class=\"gobk\" id=\"indi\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form><br></div>";
 
 } # fine if (function_exists('esegui_query'))
