@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -50,7 +50,9 @@ $var_pag[22] = 'aggiorna_restrizioni';
 $var_pag[23] = 'aggiorna';
 $var_pag[24] = 'data_agg';
 $var_pag[25] = 'commenti_prenota';
-$n_var_pag = 26;
+$var_pag[26] = 'scarica_future';
+$var_pag[27] = 'cont';
+$n_var_pag = 28;
 if (@is_array($_POST)) {
 reset($_POST);
 for ($num1 = 0 ; $num1 < count($_POST); $num1++) {
@@ -118,6 +120,7 @@ $lingua_mex = $lingua[1];
 if (defined('C_URL_MOD_EXT_CARTE_CREDITO') and C_URL_MOD_EXT_CARTE_CREDITO != "") {
 $id_utente_sessione = "-1";
 $id_sessione = crea_id_sessione($anno,$tableversioni);
+if (C_VERSIONE_ATTUALE < 3.04) $id_sessione = substr($id_sessione,0,20).substr($id_sessione,30);
 $ultimo_accesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 if ($_SERVER['REMOTE_ADDR']) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
 $REMOTE_ADDR = aggslashdb($REMOTE_ADDR);
@@ -265,7 +268,7 @@ return $errore;
 } # fine function scarica_backup_subordinazione
 
 
-function variabili_x_form (&$lista_tutti_app,&$maxocc,&$lista_regola2,&$lista_regola4,&$origini_prenota,&$campi_pers_comm,$tableappartamenti,$tableregole,$tablepersonalizza) {
+function variabili_x_form (&$lista_tutti_app,&$maxocc,&$lista_regola2,&$lista_regola3,&$origini_prenota,&$campi_pers_comm,&$num_appartamenti,$tableappartamenti,$tableregole,$tablepersonalizza) {
 
 $lista_tutti_app = "";
 $maxocc = array();
@@ -300,16 +303,20 @@ $lista_regola2[$tariffa]['napp'] = substr($lista_regola2[$tariffa]['napp'],1);
 } # fine if (substr($lista_regola2[$tariffa]['napp'],0,1) == "v")
 } # fine for $num1
 
-$lista_regola4 = array();
-$regole4 = esegui_query("select * from $tableregole where tariffa_per_persone != '' order by tariffa_per_persone");
-$num_regole4 = numlin_query($regole4);
-for ($num1 = 0 ; $num1 < $num_regole4 ; $num1++) {
-$tariffa = risul_query($regole4,$num1,'tariffa_per_persone');
-$lista_regola4[$tariffa] = risul_query($regole4,$num1,'iddatainizio');
+$lista_regola3 = array();
+$regole3 = esegui_query("select * from $tableregole where tariffa_per_persone != '' order by tariffa_per_persone");
+$num_regole3 = numlin_query($regole3);
+for ($num1 = 0 ; $num1 < $num_regole3 ; $num1++) {
+if (risul_query($regole3,$num1,'tariffa_per_persone')) {
+$tariffa = risul_query($regole3,$num1,'tariffa_per_persone');
+if (risul_query($regole3,$num1,'iddatainizio')) $lista_regola3[$tariffa] = risul_query($regole3,$num1,'iddatainizio');
+if (risul_query($regole3,$num1,'iddatafine')) $lista_regola3['min'][$tariffa] = risul_query($regole3,$num1,'iddatafine');
+} # fine if (risul_query($regole3,$num1,'tariffa_per_persone'))
 } # fine for $num1
 
 $origini_prenota = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'origini_prenota' and idutente = '1' ");
 $origini_prenota = (string) risul_query($origini_prenota,0,"valpersonalizza");
+$origini_prenota = explode(",",$origini_prenota);
 
 $campi_pers_comm = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'campi_pers_comm' and idutente = '1' ");
 if (numlin_query($campi_pers_comm) == 1) $campi_pers_comm = $campi_pers_comm = explode(">",risul_query($campi_pers_comm,0,'valpersonalizza'));
@@ -407,7 +414,7 @@ esegui_query("insert into $tableinterconnessioni (tipoid,nome_ic,idremoto1) valu
 $limite = date("YmdHis",mktime(date("H"),date("i"),(date("s") + (C_DIFF_ORE * 3600)),date("m"),(date("d") - 2),date("Y")));
 if ($ultimo_aggiornamento_tariffe < $limite) {
 $agg_tariffe_da_remoto = 1;
-variabili_x_form($lista_tutti_app,$maxocc,$lista_regola2,$lista_regola4,$origini_prenota,$campi_pers_comm,$tableappartamenti,$tableregole,$tablepersonalizza);
+variabili_x_form($lista_tutti_app,$maxocc,$lista_regola2,$lista_regola3,$origini_prenota,$campi_pers_comm,$num_appartamenti,$tableappartamenti,$tableregole,$tablepersonalizza);
 include("./includes/interconnect/$mod_ext/form.php");
 $ultimo_aggiornamento_tariffe = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
 esegui_query("update $tableinterconnessioni set idremoto1 = '$ultimo_aggiornamento_tariffe' where tipoid = 'u_agg_tar' and nome_ic = '$interconnection_name' ");
@@ -465,7 +472,7 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"./inizio.php\"><di
 
 if ($priv_crea_interconnessioni == "s") {
 
-variabili_x_form($lista_tutti_app,$maxocc,$lista_regola2,$lista_regola4,$origini_prenota,$campi_pers_comm,$tableappartamenti,$tableregole,$tablepersonalizza);
+variabili_x_form($lista_tutti_app,$maxocc,$lista_regola2,$lista_regola3,$origini_prenota,$campi_pers_comm,$num_appartamenti,$tableappartamenti,$tableregole,$tablepersonalizza);
 
 
 
@@ -730,7 +737,18 @@ include("./includes/templates/$modello_ext/form.php");
 closedir($templates_dir);
 
 
-echo "<hr style=\"width: 95%\"><div style=\"text-align: center;\">
+echo "
+<script type=\"text/javascript\">
+<!--
+var sel_memu = document.getElementsByTagName('select');
+for (var n1 = 0 ; n1 < sel_memu.length ; n1++) {
+if (sel_memu[n1].querySelector('option[selected]')) {
+sel_memu[n1].querySelector('option[selected]').selected = true;
+}
+}
+-->
+</script>
+<hr style=\"width: 95%\"><div style=\"text-align: center;\">
 <form accept-charset=\"utf-8\" method=\"post\" action=\"./personalizza.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
