@@ -33,7 +33,23 @@ $var_pag[5] = 'aggiorna_inventario';
 $var_pag[6] = 'manda_form_tab';
 $var_pag[7] = 'tipo_nuova_quantita';
 $var_pag[8] = 'modifica_quantita';
-$n_var_pag = 9;
+$var_pag[9] = 'n_id';
+$var_pag[10] = 'n_quantita_min_predef';
+$var_pag[11] = 'n_quantita';
+$var_pag[12] = 'aggiungi_bene';
+$var_pag[13] = 'lista_id_beni_in_mag_passa';
+$var_pag[14] = 'id_bene';
+$var_pag[15] = 'elimina';
+$var_pag[16] = 'elimina_cont';
+$n_var_pag = 17;
+$num2 = 0;
+if (isset($_POST['lista_id_beni_in_mag_passa'])) $num2 = $_POST['lista_id_beni_in_mag_passa'];
+elseif (isset($_GET['lista_id_beni_in_mag_passa'])) $num2 = $_GET['lista_id_beni_in_mag_passa'];
+if ($num2) {
+$num2 = explode(",",$num2);
+$num3 = count($num2);
+for ($num1 = 0 ; $num1 < $num3 ; $num1++) $var_pag[$n_var_pag++] = "n_quantita".(int) $num2[$num1];
+} # fine if ($num2)
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -296,9 +312,9 @@ if (controlla_num_pos($n_quantita_min_predef) == "SI") {
 if (!strcmp((string) $n_quantita,"")) $n_quantita = $n_quantita_min_predef;
 if (controlla_num_pos($n_quantita) == "SI") {
 $n_id = aggslashdb($n_id);
-if ($ric_checkin != "s" or $tipoid != "idappartamento" or $priv_mod_checkin != "s") $ric_checkin = "n";
+if (!isset($ric_checkin) or $ric_checkin != "s" or $tipoid != "idappartamento" or $priv_mod_checkin != "s") $ric_checkin = "n";
 if ($priv_ins_costi_agg == "n") $crea_ca = 0;
-if ($crea_ca) $tabelle_lock = array($tablenometariffe,$tableprivilegi,$tablerelinventario);
+if (!empty($crea_ca)) $tabelle_lock = array($tablenometariffe,$tableprivilegi,$tablerelinventario);
 else $tabelle_lock = array($tablerelinventario);
 $altre_tab_lock = array($tablebeniinventario);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
@@ -308,7 +324,7 @@ $n_id_in_mag = esegui_query("select idbeneinventario from $tablerelinventario wh
 if (!numlin_query($n_id_in_mag)) {
 $nome_bene = risul_query($n_id_esist,0,'nome_bene');
 
-if ($crea_ca and !$continua) {
+if (!empty($crea_ca) and empty($continua)) {
 $mostra_form_inventario = "NO";
 $nomi_esist = array();
 $nomecostoagg = $nome_bene;
@@ -373,14 +389,14 @@ echo "<div style=\"height: 5px;\"></div>
 <input type=\"hidden\" name=\"idmag\" value=\"$idmag_orig\">
 <button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form><br>";
-} # fine if ($crea_ca and !$continua)
+} # fine if (!empty($crea_ca) and empty($continua))
 
 else {
 $datainserimento = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 esegui_query("insert into $tablerelinventario (idbeneinventario,$tipoid,quantita,quantita_min_predef,richiesto_checkin,datainserimento,hostinserimento,utente_inserimento) values ('$n_id','$idmag','$n_quantita','$n_quantita_min_predef','$ric_checkin','$datainserimento','$HOSTNAME','$id_utente') ");
 $frase_modifica .= "".mex("Nuovo bene",$pag)." \"<em>$nome_bene</em>\" ".mex("aggiunto",$pag).".<br>";
 
-if ($crea_ca) {
+if (!empty($crea_ca)) {
 $prezzo_costo_agg = formatta_soldi($prezzo_costo_agg);
 if (strcmp((string) $prezzo_costo_agg,"") and controlla_soldi($prezzo_costo_agg) == "SI") {
 if (@get_magic_quotes_gpc()) $nome_costo_agg = stripslashes($nome_costo_agg);
@@ -418,8 +434,8 @@ $frase_modifica .= "<form accept-charset=\"utf-8\" method=\"post\" action=\"modi
 else $frase_modifica .= "<span class=\"colred\">".mex("Costo aggiuntivo non inserito",$pag)."</span>: ".mex("costo già esistente",$pag).".<br>";
 } # fine if (strcmp((string) $prezzo_costo_agg,"") and controlla_soldi($prezzo_costo_agg) == "SI")
 else $frase_modifica .= "<span class=\"colred\">".mex("Costo aggiuntivo non inserito",$pag)."</span>: ".mex("prezzo sbagliato",$pag).".<br>";
-} # fine if ($crea_ca)
-} # fine else if ($crea_ca and !$continua)
+} # fine if (!empty($crea_ca))
+} # fine else if (!empty($crea_ca) and empty($continua))
 
 } # fine if (!numlin_query($n_id_in_mag))
 } # fine if (numlin_query($n_id_esist))
@@ -660,13 +676,13 @@ $id_bene_in_mag = esegui_query("select idbeneinventario from $tablerelinventario
 if (numlin_query($id_bene_in_mag)) {
 $nome_bene = esegui_query("select nome_bene from $tablebeniinventario where idbeniinventario = '$id_bene'");
 $nome_bene = risul_query($nome_bene,0,'nome_bene');
-if (!$elimina_cont) {
+if (empty($elimina_cont)) {
 $mostra_form_inventario = "NO";
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine)."\">
-<input type=\"hidden\" name=\"origine_vecchia\" value=\"".htmlspecialchars($origine_vecchia)."\">
+<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars(fixstr($origine))."\">
+<input type=\"hidden\" name=\"origine_vecchia\" value=\"".htmlspecialchars(fixstr($origine_vecchia))."\">
 <input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">
 <input type=\"hidden\" name=\"idmag\" value=\"$idmag_orig\">
 <input type=\"hidden\" name=\"aggiorna_inventario\" value=\"SI\">
@@ -679,11 +695,11 @@ echo " <b>$nome_mag</b>?<br>
 <button class=\"cinv\" type=\"submit\" name=\"elimina\" value=\"1\"><div>".mex("SI",$pag)."</div></button>
 <button class=\"gobk\" type=\"submit\"><div>".mex("NO",$pag)."</div></button>
 </div></form>";
-} # fine if (!$elimina_cont)
+} # fine if (empty($elimina_cont))
 else {
 esegui_query("delete from $tablerelinventario where idbeneinventario = '$id_bene' and $tipoid = '$idmag' ");
 $frase_modifica .= "<b>".mex("Bene",$pag)." \"<em>$nome_bene</em>\" ".mex("cancellato",$pag)."</b>.<br>";
-} # fine else if (!$elimina_cont)
+} # fine else if (empty($elimina_cont))
 } # fine if (numlin_query($id_bene_in_mag))
 unlock_tabelle($tabelle_lock);
 } # fine if ($bene_permesso[$id_bene])
@@ -771,10 +787,12 @@ $nomi_beni[$idinv] = risul_query($beni_inv,$num1,'nome_bene');
 $codici_beni[$idinv] = risul_query($beni_inv,$num1,'codice_bene');
 } # fine for $num1
 
-unset($id_in_mag);
+$id_in_mag = array();
+$lista_id_beni_in_mag_passa = "";
 for ($num1 = 0 ; $num1 < $num_beni_in_mag ; $num1++) {
 $id_bene_in_mag = risul_query($beni_in_mag,$num1,'idbeneinventario',$tablerelinventario);
 if ($bene_permesso[$id_bene_in_mag]) {
+$lista_id_beni_in_mag_passa .= ",$id_bene_in_mag";
 $quantita = risul_query($beni_in_mag,$num1,'quantita',$tablerelinventario);
 $quantita_min_predef = risul_query($beni_in_mag,$num1,'quantita_min_predef',$tablerelinventario);
 $richiesto_checkin = risul_query($beni_in_mag,$num1,'richiesto_checkin',$tablerelinventario);
@@ -793,7 +811,7 @@ else {
 if (substr($diff,0,1) != "-") $diff = "+".$diff;
 $diff = "<small><small> ($diff)</small></small>";
 } # fine else if (!$diff)
-if ($aggiungi_bene and ($num1 == ($num_beni_inv - 12) or ($num1 == 0 and ($num_beni_inv - 12) < 0))) $anchor = "<a name=\"tab_inventario\"></a>";
+if (!empty($aggiungi_bene) and ($num1 == ($num_beni_inv - 12) or ($num1 == 0 and ($num_beni_inv - 12) < 0))) $anchor = "<a name=\"tab_inventario\"></a>";
 else $anchor = "";
 echo "<tr><td class=\"t1left\">$anchor$nome_bene</td>
 <td>$quantita_min_predef</td>
@@ -818,15 +836,15 @@ echo "</tr>";
 $opt_beni = "";
 for ($num1 = 0 ; $num1 < $num_beni_inv ; $num1++) {
 $idinv = risul_query($beni_inv,$num1,"idbeniinventario");
-if (!$id_in_mag[$idinv]) {
+if (empty($id_in_mag[$idinv])) {
 $opt_beni .= "<option value=\"$idinv\">".$nomi_beni[$idinv];
 if ($codici_beni[$idinv]) $opt_beni .= " (".$codici_beni[$idinv].")";
 $opt_beni .= "</option>";
-} # fine if (!$id_in_mag[$idinv])
+} # fine if (empty($id_in_mag[$idinv]))
 } # fine for $num1
 
 if ($opt_beni and $priv_ins_beni != "n") {
-if ($aggiungi_bene) $autofocus = " autofocus";
+if (!empty($aggiungi_bene)) $autofocus = " autofocus";
 else $autofocus = "";
 echo "<tr><td><select name=\"n_id\">$opt_beni</select></td>
 <td><input type=\"text\" name=\"n_quantita_min_predef\" size=\"5\"></td>
@@ -855,6 +873,7 @@ $a_bottom = "";
 } # fine else if ($num_beni_in_mag > 15)
 echo "</table></div><br><div style=\"text-align: center;\">";
 if ($priv_mod_beni != "n") echo "<button$id_modi class=\"ainv\" type=\"submit\" name=\"modifica_quantita\" value=\"".mex("Modifica le quantità attuali",$pag)."\"><div>".mex("Modifica le quantità attuali",$pag)."</div></button>";
+if ($lista_id_beni_in_mag_passa) echo "<input type=\"hidden\" name=\"lista_id_beni_in_mag_passa\" value=\"".substr($lista_id_beni_in_mag_passa,1)."\">";
 echo "</div></div></form>
 $frase_modifica<br>";
 
