@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -191,7 +191,8 @@ if ($destinatario != "tutti") $lista_utenti = ",".$destinatario.",";
 if ($anno_visione.str_replace("-","",$data_visione).$ora_visione.$min_visione < date("YmdHi",(time() + (C_DIFF_ORE * 3600)))) $datavisione = date("Y-m-d H:i",(time() + (C_DIFF_ORE * 3600))).":00";
 else $datavisione = $anno_visione.$data_visione." ".$ora_visione.":".$min_visione.":00";
 if (@get_magic_quotes_gpc()) $testo = stripslashes($testo);
-$testo = substr(htmlspecialchars($testo),0,65530);
+if (!defined('ENT_SUBSTITUTE')) define('ENT_SUBSTITUTE',ENT_IGNORE);
+$testo = substr(htmlspecialchars($testo,ENT_SUBSTITUTE),0,65530);
 $testo = aggslashdb($testo);
 $datainserimento = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 esegui_query("insert into $tablemessaggi (idmessaggi,tipo_messaggio,idutenti,idutenti_visto,datavisione,mittente,testo,datainserimento) values ('$max_mess','mess','$lista_utenti','$lista_utenti','$datavisione','$id_utente','$testo','$datainserimento')");
@@ -378,7 +379,9 @@ if (isset($info_mess[$num1]->in_reply_to)) $risposta_a = $info_mess[$num1]->in_r
 else $risposta_a = null;
 if (isset($info_mess[$num1]->references)) $riferimento = $info_mess[$num1]->references;
 else $riferimento = null;
-$oggetto = utf8_encode(imap_qprint($info_mess[$num1]->subject));
+$oggetto = imap_qprint($info_mess[$num1]->subject);
+if (function_exists('mb_convert_encoding')) $oggetto = mb_convert_encoding($oggetto,'UTF-8',mb_list_encodings());
+elseif (function_exists('utf8_encode')) $oggetto = @utf8_encode($oggetto);
 $inserisci_mess = 0;
 for ($num2 = 0 ; $num2 < $num_trova_email_tm ; $num2++) {
 if (!$mittente_email_tm[$num2] or stristr($mittente,$mittente_email_tm[$num2])) {
@@ -447,10 +450,10 @@ while (strstr($testo,"\n\n\n")) $testo = str_replace("\n\n\n","\n\n",$testo);
 } # fine if (stristr($testo,"Content-Type: text/html;") or stristr($testo,"<html>"))
 } # fine else if (stristr($testo,"Content-Type: multipart/alternative;") and...
 if (!defined('ENT_SUBSTITUTE')) define('ENT_SUBSTITUTE',ENT_IGNORE);
-$testo = htmlspecialchars($testo,ENT_SUBSTITUTE);
+$testo = substr(htmlspecialchars($testo,ENT_SUBSTITUTE),0,65530);
 $testo = aggslashdb($testo);
 $dati_richiedente = "$nome_cognome_richiedente<d><d>$mittente<d><d><d><d><d><d><d><d><d><d><d><d><d><d><d><d>";
-esegui_query("insert into $tablemessaggi (idmessaggi,tipo_messaggio,idutenti,idutenti_visto,datavisione,mittente,testo,dati_messaggio1,dati_messaggio3,dati_messaggio8,dati_messaggio15,dati_messaggio20,datainserimento) values ('$max_mess','rprenota','$lista_utenti','$lista_utenti','$datavisione','$mittente','".aggslashdb($testo)."','da_inserire','1','1','".aggslashdb($dati_richiedente)."','email','$datainserimento')");
+esegui_query("insert into $tablemessaggi (idmessaggi,tipo_messaggio,idutenti,idutenti_visto,datavisione,mittente,testo,dati_messaggio1,dati_messaggio3,dati_messaggio8,dati_messaggio15,dati_messaggio20,datainserimento) values ('$max_mess','rprenota','$lista_utenti','$lista_utenti','$datavisione','$mittente','$testo','da_inserire','1','1','".aggslashdb($dati_richiedente)."','email','$datainserimento')");
 
 # Estrazione dati da testo email
 $testo = preg_replace("/  +/"," ",str_replace("\n"," - ",$testo));
@@ -595,7 +598,10 @@ else {
 echo mex("Connessione al server",$pag)." ".$server[0]." ".mex("non riuscita!",$pag)." ".mex("Controllare i dati immessi in",$pag)." \"";
 if ($modifica_pers != "NO") echo "<a href=\"./personalizza.php?anno=$anno&id_sessione=$id_sessione#tab_mess\">".mex("configura e personalizza",$pag)."\"</a>.<br>";
 else echo "".mex("configura e personalizza\"",$pag).".<br>";
-if (stristr($server[0],"gmail.com")) echo "<br>".mex("Per gli account su gmail potrebbe essere necessario abilitare l'opzione",$pag)." \"<a rel=\"noopener noreferrer\" target=\"_blank\" href=\"https://myaccount.google.com/lesssecureapps\">Less secure app access: ON</a>\" ".mex("e/o per una volta usare prima la funzione",$pag)." \"<a rel=\"noopener noreferrer\" target=\"_blank\" href=\"https://accounts.google.com/DisplayUnlockCaptcha\">Unlock Captcha</a>\".<br><br>";
+if (stristr($server[0],"gmail.com")) {
+#echo "<br>".mex("Per gli account su gmail potrebbe essere necessario abilitare l'opzione",$pag)." \"<a rel=\"noopener noreferrer\" target=\"_blank\" href=\"https://myaccount.google.com/lesssecureapps\">Less secure app access: ON</a>\" ".mex("e/o per una volta usare prima la funzione",$pag)." \"<a rel=\"noopener noreferrer\" target=\"_blank\" href=\"https://accounts.google.com/DisplayUnlockCaptcha\">Unlock Captcha</a>\".<br><br>";
+echo "<br>".mex("Per gli account su gmail potrebbe essere necessario abilitare l'opzione",$pag)." \"<a rel=\"noopener noreferrer\" target=\"_blank\" href=\"https://myaccount.google.com/apppasswords\">App Password</a>\".<br><br>";
+} # fine if (stristr($server[0],"gmail.com"))
 } # fine else if ($email_conn)
 } # fine if (numlin_query($server_email_tab_messaggi))
 unlock_tabelle($tabelle_lock);
@@ -795,7 +801,7 @@ if ($priv_mod_prenotazioni == "g" and empty($utenti_gruppi[$utente_ins_prenota])
 if ($priv_mod_prenota_iniziate != "s" and $id_periodo_corrente >= $id_data_ini_prenota) $link_modifica = "NO";
 if ($priv_mod_prenota_ore != "000") {
 $adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
-$limite = date("YmdHis",mktime((substr($data_ins_prenota,11,2) + $priv_mod_prenota_ore),substr($data_ins_prenota,14,2),substr($data_ins_prenota,17,2),substr($data_ins_prenota,5,2),substr($data_ins_prenota,8,2),substr($data_ins_prenota,0,4)));
+$limite = date("YmdHis",mktime((substr($data_ins_prenota,11,2) + (int) $priv_mod_prenota_ore),substr($data_ins_prenota,14,2),substr($data_ins_prenota,17,2),substr($data_ins_prenota,5,2),substr($data_ins_prenota,8,2),substr($data_ins_prenota,0,4)));
 if ($adesso > $limite) $link_modifica = "NO";
 } # fine if ($priv_mod_prenota_ore != "000")
 if ($link_modifica == "SI") {
@@ -962,7 +968,7 @@ $oracheckin = $oracheckin.":00";
 } # fine if ($oracheckin)
 $metodo_pagamento = $dati_richiedente_dt[17];
 $commento = fixset($dati_richiedente_dt[20]);
-$commenti_pers = explode(">",fixset($dati_richiedente_dt[21]));
+$commenti_pers = explode(">",fixstr($dati_richiedente_dt[21]));
 $num_commenti_pers = count($commenti_pers);
 if ($num_commenti_pers < 1) $num_commenti_pers = 1;
 $campi_pers_clienti = fixset($dati_richiedente_dt[22]);
