@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -347,10 +347,10 @@ ${"n_numpiano".$num1} = elimina_caratteri_slash(${"n_numpiano".$num1});
 ${"n_numpiano".$num1} = htmlspecialchars(${"n_numpiano".$num1});
 ${"n_maxoccupanti".$num1} = elimina_caratteri_slash(${"n_maxoccupanti".$num1});
 ${"n_priorita".$num1} = elimina_caratteri_slash(${"n_priorita".$num1});
-${"n_app_vicini".$num1} = elimina_caratteri_slash(fixset(${"n_app_vicini".$num1}));
+${"n_app_vicini".$num1} = elimina_caratteri_slash(${"n_app_vicini".$num1});
 ${"n_app_vicini".$num1} = htmlspecialchars(${"n_app_vicini".$num1});
-if (controlla_num(${"n_maxoccupanti".$num1}) != "SI") unset(${"n_maxoccupanti".$num1});
-if (controlla_num(${"n_priorita".$num1}) != "SI") unset(${"n_priorita".$num1});
+if (controlla_num(${"n_maxoccupanti".$num1}) != "SI") ${"n_maxoccupanti".$num1} = "";
+if (controlla_num(${"n_priorita".$num1}) != "SI") ${"n_priorita".$num1} = "";
 ${"n_commento".$num1} = htmlspecialchars(fixstr(${"n_commento".$num1}));
 ${"d_numcasa".$num1} = htmlspecialchars(${"d_numcasa".$num1});
 ${"d_numpiano".$num1} = htmlspecialchars(${"d_numpiano".$num1});
@@ -411,7 +411,7 @@ $n_commento = ${"n_commento".$num1};
 $n_nome_app = (string) ${"n_nome_app".$num1};
 $n_numcasa = ${"n_numcasa".$num1};
 $n_numpiano = ${"n_numpiano".$num1};
-$n_maxoccupanti = ${"n_maxoccupanti".$num1};
+$n_maxoccupanti = fixset(${"n_maxoccupanti".$num1});
 $n_priorita = ${"n_priorita".$num1};
 $n_app_vicini = ${"n_app_vicini".$num1};
 ${"d_app_vicini".$num1} = esegui_query("select app_vicini from $tableappartamenti where idappartamenti = '".aggslashdb($idappartamenti)."' ");
