@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -34,6 +34,22 @@ if (isset($_POST['id_prenota'])) $num2 = (int) $_POST['id_prenota'];
 elseif (isset($_GET['id_prenota'])) $num2 = (int) $_GET['id_prenota'];
 if ($num2) {
 $var_pag[$n_var_pag++] = "num_ospiti_inviati$num2";
+$var_pag[$n_var_pag++] = "principale$num2";
+$var_pag[$n_var_pag++] = "nazione$num2"."_1";
+$var_pag[$n_var_pag++] = "regione$num2"."_1";
+$var_pag[$n_var_pag++] = "citta$num2"."_1";
+$var_pag[$n_var_pag++] = "documento$num2"."_1";
+$var_pag[$n_var_pag++] = "giornoscaddoc$num2"."_1";
+$var_pag[$n_var_pag++] = "mesescaddoc$num2"."_1";
+$var_pag[$n_var_pag++] = "annoscaddoc$num2"."_1";
+$var_pag[$n_var_pag++] = "nazionedoc$num2"."_1";
+$var_pag[$n_var_pag++] = "regionedoc$num2"."_1";
+$var_pag[$n_var_pag++] = "cittadoc$num2"."_1";
+$var_pag[$n_var_pag++] = "id_osp_num$num2"."_0";
+$num4 = 0;
+if (isset($_POST["id_osp_num$num2"."_0"])) $num4 = (int) $_POST["id_osp_num$num2"."_0"];
+elseif (isset($_GET["id_osp_num$num2"."_0"])) $num4 = (int) $_GET["id_osp_num$num2"."_0"];
+if ($num4) $var_pag[$n_var_pag++] = "cliente_ospite$num2"."_$num4";
 $num3 = 0;
 if (isset($_POST["num_ospiti_inviati$num2"])) $num3 = (int) $_POST["num_ospiti_inviati$num2"];
 elseif (isset($_GET["num_ospiti_inviati$num2"])) $num3 = (int) $_GET["num_ospiti_inviati$num2"];
@@ -199,7 +215,7 @@ $adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
 $data_ins = esegui_query("select datainserimento from $tableprenota where idprenota = '$id_prenota'");
 if (numlin_query($data_ins) == 1) $data_ins = risul_query($data_ins,0,'datainserimento');
 else $data_ins = "1971-01-01 00:00:00";
-$limite = date("YmdHis",mktime((substr($data_ins,11,2) + $priv_mod_prenota_ore),substr($data_ins,14,2),substr($data_ins,17,2),substr($data_ins,5,2),substr($data_ins,8,2),substr($data_ins,0,4)));
+$limite = date("YmdHis",mktime((substr($data_ins,11,2) + (int) $priv_mod_prenota_ore),substr($data_ins,14,2),substr($data_ins,17,2),substr($data_ins,5,2),substr($data_ins,8,2),substr($data_ins,0,4)));
 if ($adesso > $limite) $priv_mod_prenotazioni = "n";
 } # fine if ($priv_mod_prenota_ore != "000")
 } # fine for $num_idpr
@@ -295,14 +311,14 @@ $lista_ospiti = array('lista' => null);
 $presente_id = array();
 $idclienti_compagni = "";
 $num_ospiti = 0;
-if (${"cliente_ospite".$id_prenota."_".$idclienti} == "SI") {
+if (isset(${"cliente_ospite".$id_prenota."_".$idclienti}) and ${"cliente_ospite".$id_prenota."_".$idclienti} == "SI") {
 $num_ospiti++;
 $lista_ospiti[$num_ospiti] = $idclienti;
 $lista_ospiti['lista'] .= $idclienti.",";
 $presente_id[$idclienti] = "SI";
 $idclienti_compagni .= substr($compagni_cliente,1);
 $principale = $idclienti;
-} # fine if (${"cliente_ospite".$id_prenota."_".$idclienti} == "SI")
+} # fine if (isset(${"cliente_ospite".$id_prenota."_".$idclienti}) and ${"cliente_ospite".$id_prenota."_".$idclienti} == "SI")
 else if (${"id_osp_num".$id_prenota."_1"} == $idclienti) esegui_query("delete from $tablerclientiprenota where idprenota = '$id_prenota' and idclienti = '$idclienti' ");
 
 $ospiti = esegui_query("select idclienti,num_ordine,parentela from $tablerclientiprenota where idprenota = '$id_prenota' order by num_ordine ");
@@ -568,7 +584,7 @@ else {
 $checked = "";
 echo "<br>".addslashes(mex("Parentela",$pag)).": ".mostra_lista_relutenti("parentela_$id_prenota"."_$id_clienti_osp",$parentela_osp,$id_utente,"nome_parentela","idparentele","idparentela",$tableparentele,$tablerelutenti)."";
 } # fine else if ($num1 == 0)
-if ($cliente_ospite != "SI") echo "<br><input name=\"principale$id_prenota\" value=\"$id_clienti_osp\" type=\"radio\"$checked>".mex("Ospite principale",$pag)." ";
+if (!isset($cliente_ospite) or $cliente_ospite != "SI") echo "<br><input name=\"principale$id_prenota\" value=\"$id_clienti_osp\" type=\"radio\"$checked>".mex("Ospite principale",$pag)." ";
 } # fine if ($mostra_osp == "SI")
 echo "<br>
 <input type=\"hidden\" name=\"id_osp_num$id_prenota"."_".($num1 + 1)."\" value=\"$id_clienti_osp\">";
@@ -577,7 +593,8 @@ $idclienti_compagni .= substr(risul_query($dati_ospite,0,'idclienti_compagni'),1
 $mostra_osp = "SI";
 } # fine for $num1
 if ($num_ospiti == 0) {
-echo "<br><label><input name=\"cliente_ospite".$id_prenota."_".$idclienti."\" value=\"SI\" type=\"checkbox\"> ".mex("Ospite della prenotazione",$pag)."</label><br>";
+echo "<br><input type=\"hidden\" name=\"id_osp_num$id_prenota"."_0\" value=\"$idclienti\">
+<label><input name=\"cliente_ospite".$id_prenota."_".$idclienti."\" value=\"SI\" type=\"checkbox\"> ".mex("Ospite della prenotazione",$pag)."</label><br>";
 } # fine if ($num_ospiti == 0)
 
 if ($num_persone_tot > $num1) $num_fine = $num_persone_tot;
