@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -31,7 +31,12 @@ $var_pag[3] = 'cerca_inizioperiodo';
 $var_pag[4] = 'cerca_anno_inizioperiodo';
 $var_pag[5] = 'cerca_fineperiodo';
 $var_pag[6] = 'cerca_anno_fineperiodo';
-$n_var_pag = 7;
+$var_pag[7] = 'azzera_soldi';
+$var_pag[8] = 'continua';
+$var_pag[9] = 'id_transazione';
+$var_pag[10] = 'pagina_prenota';
+$var_pag[11] = 'cambia_colori';
+$n_var_pag = 12;
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -124,6 +129,7 @@ $stile_data = stile_data();
 $Euro = nome_valuta();
 
 if (!empty($senza_colori)) $senza_colori = "SI";
+else $senza_colori = "";
 if (!empty($pagina_prenota) and controlla_num_pos($pagina_prenota) != "SI") $pagina_prenota = "";
 
 
@@ -186,7 +192,7 @@ echo "<table class=\"buttonbar\"><tr><td align=\"left\">
 <form accept-charset=\"utf-8\" method=\"post\" action=\"storia_soldi.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input type=\"hidden\" name=\"senza_colori\" value=\"".htmlspecialchars(fixstr($senza_colori))."\">
+<input type=\"hidden\" name=\"senza_colori\" value=\"$senza_colori\">
 <input type=\"hidden\" name=\"metodo_selezionato\" value=\"".htmlspecialchars(fixstr($metodo_selezionato))."\">
 <input class=\"sbutton\" type=\"submit\" name=\"cerca_prenota\" value=\"".mex("Vedi le modifiche",$pag)."\">
  ".mex("dal",$pag)." <select name=\"cerca_inizioperiodo\">
@@ -286,7 +292,7 @@ $frase_periodo .= " ".mex("fino al",$pag)." $cerca_fineperiodo_f";
 
 $saldo_prenota_TOT = 0;
 $saldo_valuta_TOT = array();
-if (!isset($senza_colori)) $class = "t1 t1color";
+if (!$senza_colori) $class = "t1 t1color";
 else $class = "t1wc";
 
 $tutti_utenti = esegui_query("select * from $tableutenti order by idutenti");
@@ -341,7 +347,7 @@ else $stringa_pagine .= "</b>";
 } # fine for $num1
 $stringa_pagine .= "</div>";
 echo $stringa_pagine;
-$colonne = 10;
+$colonne = 11;
 if ($num_tutti_utenti > 1) $colonne++;
 $stringa_puntini_tab = "<tr><td colspan=\"$colonne\">...</td></tr>";
 } # fine if ($num_storia_soldi_prenota > $num_vedi_in_tab)
@@ -354,10 +360,11 @@ echo "<div class=\"tab_cont\">
 <td class=\"t1top\" rowspan=2>".mex("Pagato prima",$pag)."</td>
 <td class=\"t1top\" rowspan=2>".mex("Pagato dopo",$pag)."</td>
 <td class=\"t1top\" rowspan=2>".mex("Saldo",$pag)."</td>
+<td class=\"t1top\" rowspan=2>".mex("Metodo",$pag)."</td>
 <td class=\"t1top\" rowspan=2>".mex("Id",$pag)."</td>
-<td class=\"t1top\" rowspan=2>".mex("Metodo",$pag)."</td>";
+<td class=\"t1top\" rowspan=2>".mex("Note",$pag)."</td>";
 if ($num_tutti_utenti > 1) echo "<td class=\"t1top\" rowspan=2>".mex("Utente",$pag)."</td>";
-echo "<td class=\"t1top\" rowspan=2>".mex("Data_della modifica",$pag)."</td></tr>
+echo "<td class=\"t1top\" rowspan=2>".str_replace("_","&nbsp;",mex("Data_della modifica",$pag))."</td></tr>
 <tr><td>".mex("N°",$pag)."</td>
 <td>".str_replace("_","&nbsp;",mex("Cognome_cliente",$pag))."</td>
 <td class=\"t1top\">".str_replace("_","&nbsp;",mex("Data_iniziale",$pag))."</td>
@@ -366,11 +373,10 @@ echo "<td class=\"t1top\" rowspan=2>".mex("Data_della modifica",$pag)."</td></tr
 if (!$cerca_prenota and $num_storia_soldi_prenota > $num_vedi_in_tab and $pagina_prenota != 1) echo $stringa_puntini_tab;
 
 for ($num1 = 0 ; $num1 < $num_storia_soldi_prenota ; $num1 = $num1 + 1) {
-$data_inserimento = risul_query($storia_soldi_prenota,$num1,'data_inserimento');
-$data_inserimento = substr($data_inserimento, 0, 10);
+$data_inserimento = substr(risul_query($storia_soldi_prenota,$num1,'data_inserimento'),0,10);
 $data_inserimento_f = formatta_data($data_inserimento,$stile_data);
-#$string = substr($data_inserimento, 6, 9);
-#$data_inserimento = preg_replace("/$string/","",$data_inserimento);
+$data_transazione = substr(risul_query($storia_soldi_prenota,$num1,'data_transazione'),0,10);
+if ($data_inserimento != $data_transazione) $data_inserimento_f .= " <small>(".formatta_data($data_transazione,$stile_data).")</small>";
 $motivazione = risul_query($storia_soldi_prenota,$num1,'motivazione');
 $motivazione = explode(";",$motivazione);
 $cognome = esegui_query("select cognome,utente_inserimento from $tableclienti where idclienti = '".$motivazione[0]."'");
@@ -419,7 +425,7 @@ if ($priv_mod_prenota_iniziate != "s" and $id_periodo_corrente >= $iddatainizio)
 if ($priv_mod_prenota_ore != "000") {
 $adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
 $data_ins = risul_query($prenota_esist,0,'datainserimento');
-$limite = date("YmdHis",mktime((substr($data_ins,11,2) + $priv_mod_prenota_ore),substr($data_ins,14,2),substr($data_ins,17,2),substr($data_ins,5,2),substr($data_ins,8,2),substr($data_ins,0,4)));
+$limite = date("YmdHis",mktime((substr($data_ins,11,2) + (int) $priv_mod_prenota_ore),substr($data_ins,14,2),substr($data_ins,17,2),substr($data_ins,5,2),substr($data_ins,8,2),substr($data_ins,0,4)));
 if ($adesso > $limite) $link_modifica = 0;
 } # fine if ($priv_mod_prenota_ore != "000")
 if ($link_modifica) $num_prenota = "<a$stilebarrato href=\"modifica_prenota.php?id_prenota=$num_prenota$pcanc&amp;anno=$anno&amp;id_sessione=$id_sessione&amp;origine=storia_soldi.php\">$num_prenota</a>";
@@ -434,8 +440,18 @@ $soldi_dopo = $soldi_prima + $saldo_prenota;
 $saldo_prenota_TOT = $saldo_prenota_TOT + $saldo_prenota;
 $id_pagamento = risul_query($storia_soldi_prenota,$num1,'id_pagamento');
 if (!$id_pagamento) $id_pagamento = "&nbsp;";
+else {
+if (strlen($id_pagamento) > 36) $id_pagamento = "<small><small>$id_pagamento</small></small>";
+elseif (strlen($id_pagamento) > 24) $id_pagamento = "<small>$id_pagamento</small>";
+} # fine else if (!$id_pagamento)
 $metodo_pagamento = risul_query($storia_soldi_prenota,$num1,'metodo_pagamento');
 if (!$metodo_pagamento) $metodo_pagamento = "&nbsp;";
+$note_pagamento = risul_query($storia_soldi_prenota,$num1,'note');
+if (!$note_pagamento) $note_pagamento = "&nbsp;";
+else {
+if (strlen($note_pagamento) > 36) $note_pagamento = "<small><small>$note_pagamento</small></small>";
+elseif (strlen($note_pagamento) > 24) $note_pagamento = "<small>$note_pagamento</small>";
+} # fine else if (!$note_pagamento)
 $utente_inserimento = risul_query($storia_soldi_prenota,$num1,'utente_inserimento');
 $nome_utente_inserimento = $nome_utente_id[$utente_inserimento];
 
@@ -466,10 +482,11 @@ echo "<tr><td>$num_prenota</td>
 <td>$soldi_prima_p</td>
 <td>$soldi_dopo_p</td>
 <td>$saldo_prenota_vedi</td>
+<td>$metodo_pagamento</td>
 <td>$id_pagamento</td>
-<td>$metodo_pagamento</td>";
+<td>$note_pagamento</td>";
 if ($num_tutti_utenti > 1) echo "<td><small>$nome_utente_inserimento</small></td>";
-echo "<td><small>$data_inserimento_f</small></td></tr>";
+echo "<td>$data_inserimento_f</td></tr>";
 
 } # fine if ($cerca_prenota or (...
 
@@ -492,6 +509,7 @@ echo "<tr><td colspan=6><b>".mex("TOTALE",$pag)."</b></td>
 if ($num_tutti_utenti > 1) echo "<td>&nbsp;</td>";
 echo "<td>&nbsp;</td>
 <td>&nbsp;</td>
+<td>&nbsp;</td>
 <td>&nbsp;</td></tr>";
 
 $costo_cassa = esegui_query("select * from $tablecosti where idcosti = 0");
@@ -505,12 +523,14 @@ echo "<tr><td colspan=\"6\"><b><i>".mex("Trasferito in cassa",$pag).":</i></b></
 if ($num_tutti_utenti > 1) echo "<td>&nbsp;</td>";
 echo "<td>&nbsp;</td>
 <td>&nbsp;</td>
+<td>&nbsp;</td>
 <td>&nbsp;</td></tr>
 <tr><td colspan=\"6\"><b><i>".mex("RESTO",$pag)."</i></b></td>
 <td>$resto_tot_p</td>";
 if ($num_tutti_utenti > 1) echo "<td>&nbsp;</td>";
 echo "<td>&nbsp;</td>
 <td>&nbsp;</td>
+<td>&nbsp;</td>
 <td>&nbsp;</td></tr>";
 } # fine if ($costo_cassa and !$cerca_prenota)
 
