@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -1032,10 +1032,14 @@ if ($priv_mod_reg2 == "s") echo " <a style=\"display: inline-block; margin-botto
 echo "<br><br>";
 
 $regola4 = esegui_query("select * from $tableregole where tariffa_per_persone = '".$tariffa[1]."' ");
-if (numlin_query($regola4)) $num_pers_reg4 = risul_query($regola4,0,'iddatainizio');
+if (numlin_query($regola4) and risul_query($regola4,0,'iddatainizio')) $num_pers_reg4 = risul_query($regola4,0,'iddatainizio');
 else $num_pers_reg4 = mex("non definito",$pag);
+if (numlin_query($regola4) and risul_query($regola4,0,'iddatafine')) $num_pers_reg4m = risul_query($regola4,0,'iddatafine');
+else $num_pers_reg4m = mex("non definito",$pag);
 echo mex("Numero di persone predefinito per la tariffa",$pag)." \"".$nometariffa_vedi[1]."\": <em>$num_pers_reg4</em>.";
-if ($priv_mod_reg2 == "s") echo " <a style=\"display: inline-block; margin-bottom: 2px;\" href=\"./crearegole.php?id_sessione=$id_sessione&amp;anno=$anno&amp;tipotariffa_regola3=".$tariffa[1]."&amp;origine=tab_tariffa\">".mex("Modifica la regola di assegnazione",'interconnessioni.php')." 3</a>";
+if ($priv_mod_reg2 == "s") echo " <a style=\"display: inline-block; margin-bottom: 2px;\" href=\"./crearegole.php?id_sessione=$id_sessione&amp;anno=$anno&amp;tipotariffa_regola3=".$tariffa[1]."&amp;nor3m=1&amp;origine=tab_tariffa\">".mex("Modifica la regola di assegnazione",'interconnessioni.php')." 3</a>";
+echo "<br><br>".mex("Numero di persone minimo per la tariffa",$pag)." \"".$nometariffa_vedi[1]."\": <em>$num_pers_reg4m</em>.";
+if ($priv_mod_reg2 == "s") echo " <a style=\"display: inline-block; margin-bottom: 2px;\" href=\"./crearegole.php?id_sessione=$id_sessione&amp;anno=$anno&amp;tipotariffa_regola3=".$tariffa[1]."&amp;nor3=1&amp;origine=tab_tariffa\">".mex("Modifica la regola di assegnazione",'interconnessioni.php')." 3</a>";
 echo "<br><br><br>";
 
 if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa1] == "SI") {
