@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -51,7 +51,9 @@ $var_pag[19] = 'n_commento';
 $var_pag[20] = 'n_cancella_commento';
 $var_pag[21] = 'tableprenota_da_aggiornare';
 $var_pag[22] = 'torna_indietro';
-$n_var_pag = 23;
+$var_pag[23] = 'dati_prn';
+$var_pag[24] = 'tipo_sposta';
+$n_var_pag = 25;
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -72,6 +74,8 @@ $tablecostiprenota = $PHPR_TAB_PRE."costiprenota".$anno;
 
 $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
 if ($id_utente) {
+$tariffe_consentite_vett = array();
+$contratti_consentiti_vett = array();
 
 if ($id_utente != 1) {
 $prendi_gruppi = "";
@@ -121,7 +125,6 @@ $tariffe_consentite = risul_query($privilegi_annuali_utente,0,'tariffe_consentit
 $attiva_tariffe_consentite = substr($tariffe_consentite,0,1);
 if ($attiva_tariffe_consentite == "s") {
 $tariffe_consentite = explode(",",substr($tariffe_consentite,2));
-unset($tariffe_consentite_vett);
 for ($num1 = 0 ; $num1 < count($tariffe_consentite) ; $num1++) if ($tariffe_consentite[$num1]) $tariffe_consentite_vett[$tariffe_consentite[$num1]] = "SI";
 } # fine if ($attiva_tariffe_consentite == "s")
 $priv_ins_nuove_prenota = substr($priv_ins_prenota,0,1);
@@ -136,10 +139,9 @@ $contratti_consentiti = risul_query($privilegi_annuali_utente,0,'contratti_conse
 $attiva_contratti_consentiti = substr($contratti_consentiti,0,1);
 if ($attiva_contratti_consentiti == "s") {
 $contratti_consentiti = explode(",",$contratti_consentiti);
-unset($contratti_consentiti_vett);
 for ($num1 = 1 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
 } # fine if ($attiva_contratti_consentiti == "s")
-$cassa_pagamenti = risul_query($privilegi_annuali_utente,0,'cassa_pagamenti');
+$cassa_pagamenti = (string) risul_query($privilegi_annuali_utente,0,'cassa_pagamenti');
 } # fine else if (numlin_query($privilegi_annuali_utente) == 0)
 
 if ($priv_app_gruppi == "SI") {
@@ -206,12 +208,14 @@ $priv_mod_prenotazioni_gr[$idutente_gruppo] = "n";
 } # fine if ($id_utente != 1)
 else {
 $anno_utente_attivato = "SI";
+$priv_ins_clienti = "s";
 $vedi_clienti = "SI";
 $priv_ins_periodi_passati = "s";
 $priv_mod_prenotazioni = "s";
 $priv_mod_date = "s";
 $priv_mod_assegnazione_app = "s";
 $priv_mod_commento = "s";
+$priv_mod_tariffa = "s";
 $priv_mod_sconto = "s";
 $priv_mod_caparra = "s";
 $priv_mod_pagato = "s";
@@ -381,7 +385,7 @@ else {
 $idg_ini = $idg_agg - $loop + 1;
 $idg_fine = $idg_agg;
 } # fine else if ($direz == "dx")
-unset($reg1_chiuso);
+$reg1_chiuso = array();
 $app_agenzia = esegui_query("select * from $tableregole where app_agenzia != '' and motivazione2 = 'x' and iddatainizio <= '$idg_fine' and iddatafine >= '$idg_ini' ");
 $num_app_agenzia = numlin_query($app_agenzia);
 for ($num1 = 0 ; $num1 < $num_app_agenzia ; $num1++) {
@@ -468,7 +472,7 @@ if ($priv_mod_prenotazioni == "g" and !$utenti_gruppi[$utente_inserimento]) $lin
 if ($priv_mod_prenota_iniziate != "s" and $id_periodo_corrente >= $iddatainizio) $link_modifica = 0;
 if ($priv_mod_prenota_ore != "000") {
 $adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
-$limite = date("YmdHis",mktime((substr($data_ins_js,11,2) + $priv_mod_prenota_ore),substr($data_ins_js,14,2),substr($data_ins_js,17,2),substr($data_ins_js,5,2),substr($data_ins_js,8,2),substr($data_ins_js,0,4)));
+$limite = date("YmdHis",mktime((substr($data_ins_js,11,2) + (int) $priv_mod_prenota_ore),substr($data_ins_js,14,2),substr($data_ins_js,17,2),substr($data_ins_js,5,2),substr($data_ins_js,8,2),substr($data_ins_js,0,4)));
 if ($adesso > $limite) $link_modifica = 0;
 } # fine if ($priv_mod_prenota_ore != "000")
 if (!$link_modifica) $dati_prenota_extra .= "<lm>1</lm>";
@@ -476,7 +480,7 @@ if (!$link_modifica) $dati_prenota_extra .= "<lm>1</lm>";
 
 else {
 $cognome = "&amp;nbsp;";
-$colore = "#777777";
+$colore = "closed";
 $app_ass_js = "k";
 $data_ins_js = "1";
 if ($direz == "dx") $pren_prec = esegui_query("select utente_inserimento from $tableprenota where iddatafine = '".($idg_agg - 1)."' and idappartamenti = '$id_appartamento'$cond_per_corr ");
@@ -517,15 +521,15 @@ for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1++) {
 $id_appartamento = risul_query($appartamenti,$num1,'idappartamenti');
 if ($priv_vedi_tab_mesi != "p" or $appartamenti_consentiti[$id_appartamento] != "NO") {
 if (!strstr($dati_prenota,"<app id=\"$id_appartamento\">")) {
-if (isset($reg1_chiuso) and $reg1_chiuso[$id_appartamento][$idg_agg]) {
+if (isset($reg1_chiuso[$id_appartamento][$idg_agg])) {
 $dati_prenota .= "<app id=\"$id_appartamento\">
 <ln>1</ln><idpr>-1</idpr>
 <cogn>&amp;nbsp;</cogn>
-<clr>#777777</clr>
+<clr>closed</clr>
 <apas>k</apas>
 <dain>1</dain>
 </app>";
-} # fine if (isset($reg1_chiuso) and $reg1_chiuso[$id_appartamento][$idg_agg])
+} # fine if (isset($reg1_chiuso[$id_appartamento][$idg_agg]))
 } # fine if (!strstr($dati_prenota,"<app id=\"$id_appartamento\">"))
 } # fine if ($priv_vedi_tab_mesi != "p" or $appartamenti_consentiti[$id_appartamento] != "NO")
 } # fine for $num1
@@ -564,7 +568,7 @@ if ($id_periodo_corrente >= $iddatainizio) $link_modifica = 0;
 $data_ins = risul_query($dati_prn,0,'datainserimento');
 if ($priv_mod_prenota_ore != "000") {
 $adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
-$limite = date("YmdHis",mktime((substr($data_ins,11,2) + $priv_mod_prenota_ore),substr($data_ins,14,2),substr($data_ins,17,2),substr($data_ins,5,2),substr($data_ins,8,2),substr($data_ins,0,4)));
+$limite = date("YmdHis",mktime((substr($data_ins,11,2) + (int) $priv_mod_prenota_ore),substr($data_ins,14,2),substr($data_ins,17,2),substr($data_ins,5,2),substr($data_ins,8,2),substr($data_ins,0,4)));
 if ($adesso > $limite) $link_modifica = 0;
 } # fine if ($priv_mod_prenota_ore != "000")
 if ($link_modifica) {
@@ -590,21 +594,21 @@ $dati_cat_pers = dati_cat_pers($id_utente,$tablepersonalizza,$lingua_mex,"v",0,1
 $dati_cap = dati_costi_agg_prenota($tablecostiprenota,$id_prn,$dati_cat_pers);
 unset($num_letti_agg);
 for ($numca = 0 ; $numca < $dati_cap['num'] ; $numca++) aggiorna_letti_agg_in_periodi($dati_cap,$numca,$num_letti_agg,$iddatainizio,$iddatafine,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],"","",$dati_cat_pers);
-if ($num_persone or $num_letti_agg['max']) {
+if ($num_persone or !empty($num_letti_agg['max'])) {
 $dati_xml .= "\n-".mex("Nº di persone",$pag).": $num_persone ";
-if ($num_letti_agg['max']) $dati_xml .= "+ ".$num_letti_agg['max']." ";
+if (!empty($num_letti_agg['max'])) $dati_xml .= "+ ".$num_letti_agg['max']." ";
 if ($dati_cat_pers['num']) {
 $d_cat_persone = dati_cat_pers_p($dati_prn,0,$dati_cat_pers,$num_persone,$lingua_mex,0);
-if ($d_cat_persone['num'] > 1 or ($d_cat_persone['num'] and $num_letti_agg['max'])) $dati_xml .= "\n ";
+if ($d_cat_persone['num'] > 1 or ($d_cat_persone['num'] and !empty($num_letti_agg['max']))) $dati_xml .= "\n ";
 $dati_xml .= "(";
 for ($num1 = 0 ; $num1 < $d_cat_persone['num'] ; $num1++) {
 if ($num1 > 0) $dati_xml .= ", ";
 $dati_xml .= $d_cat_persone[$num1]['molt']." ".$d_cat_persone[$num1]['n_corr'];
 } # fine for $num1
-if ($num_letti_agg['max']) $dati_xml .= $num_letti_agg['catp'][$num_letti_agg['sett_max']];
+if (!empty($num_letti_agg['max'])) $dati_xml .= $num_letti_agg['catp'][$num_letti_agg['sett_max']];
 $dati_xml .= ") ";
 } # fine if ($dati_cat_pers['num'])
-} # fine if ($num_persone or $num_letti_agg['max'])
+} # fine if ($num_persone or !empty($num_letti_agg['max']))
 $tariffa = risul_query($dati_prn,0,'tariffa');
 if ($tariffa and $priv_mod_tariffa != "n") {
 $tariffa = explode("#@&",$tariffa);
@@ -617,7 +621,7 @@ if ($origine) $dati_xml .= "\n-".mex("Origine",$pag).": ".str_replace("\"","&quo
 $data_inserimento = formatta_data(substr($data_ins,0,-3),$stile_data);
 $dati_xml .= "\n-".mex("Data inserimento",$pag).": ".str_replace("\"","&quot;",str_replace(">","&gt;",str_replace("<","&lt;",str_replace("&","&amp;",$data_inserimento))))." ";
 if ($priv_vedi_commento == "s" and $iddatainizio != 0) {
-$commento = risul_query($dati_prn,0,'commento');
+$commento = (string) risul_query($dati_prn,0,'commento');
 if (strstr($commento,">")) {
 $commento = explode(">",$commento);
 $commento = $commento[0];
@@ -629,7 +633,7 @@ $Euro = nome_valuta();
 $stile_soldi = stile_soldi();
 $tariffa_tot = risul_query($dati_prn,0,'tariffa_tot');
 $dati_xml .= "\n-".mex("Totale da pagare",$pag).": ".punti_in_num($tariffa_tot,$stile_soldi)." $Euro ";
-$valuta_tariffa = explode(">",risul_query($dati_prn,0,'valuta'));
+$valuta_tariffa = explode(">",(string) risul_query($dati_prn,0,'valuta'));
 if ($valuta_tariffa[0]) {
 $valuta_tariffa = explode("<",$valuta_tariffa[0]);
 $cambio_tariffa = $valuta_tariffa[1];
@@ -806,6 +810,18 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 <button type=\"submit\" class=\"wbutton\"><img src=\"./img/dir3_sin.png\" alt=\"&lt;--\"></button>
 &nbsp;&nbsp;&nbsp;&nbsp;</div></form>";
 } # fine if ($mese != 1)
+else {
+if (@is_file(C_DATI_PATH."/selectperiodi".($anno - 1).".1.php")) {
+echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"inizio.php#vai_anno\"><div style=\"white-space: nowrap;\">
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"vai_anno\" value=\"".($anno - 1)."\">
+<input class=\"sbutton\" type=\"submit\" value=\"".ucfirst(mex("richiedi l'anno",'inizio.php'))." ".($anno - 1)."\">
+&nbsp;&nbsp;&nbsp;&nbsp;
+</div></form>";
+} # fine if (@is_file(C_DATI_PATH."/selectperiodi".($anno - 1).".1.php")) 
+else echo "&nbsp;";
+} # fine else if ($mese != 1)
 echo "</td><td align=\"center\">
 <h3 id=\"h_mon\">".mex("Tabella prenotazioni del",$pag)." <span id=\"m_corr_su\">$mese_mostra-$anno_mostra</span>.</h3>
 </td><td style=\"width: 100px;\" align=\"left\">";
@@ -867,7 +883,7 @@ else $appartamenti_consentiti = trova_app_consentiti($appartamenti,$num_appartam
 } # fine if ($priv_vedi_tab_mesi == "p")
 
 # regole 1 di chiusura
-unset($reg1_chiuso);
+$reg1_chiuso = array();
 $app_agenzia = esegui_query("select * from $tableregole where app_agenzia != '' and motivazione2 = 'x' ");
 $num_app_agenzia = numlin_query($app_agenzia);
 for ($num1 = 0 ; $num1 < $num_app_agenzia ; $num1++) {
@@ -907,11 +923,11 @@ unset($app_canc_trovato);
 for ($num1 = 0 ; $num1 < $num_prenota_app_canc; $num1 = $num1 + 1) {
 $cond_app_canc .= " and $tableprenota.idprenota != '".risul_query($prenota_app_canc,$num1,'idprenota')."' ";
 $idapp_prenota_app_canc = risul_query($prenota_app_canc,$num1,'idappartamenti');
-if ($app_canc_trovato[$idapp_prenota_app_canc] != "SI") {
+if (!isset($app_canc_trovato[$idapp_prenota_app_canc]) or $app_canc_trovato[$idapp_prenota_app_canc] != "SI") {
 $app_canc_trovato[$idapp_prenota_app_canc] = "SI";
 $app_canc[$num_app_canc] = $idapp_prenota_app_canc;
 $num_app_canc++;
-} # fine if ($app_canc_trovato[$idapp_prenota_app_canc] != "SI")
+} # fine if (!isset($app_canc_trovato[$idapp_prenota_app_canc]) or $app_canc_trovato[$idapp_prenota_app_canc] != "SI")
 } # fine for $num1
 
 $allinea_tab_mesi = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'allinea_tab_mesi' and idutente = '$id_utente'");
@@ -1061,10 +1077,10 @@ if ($esiste == 1) $utente_inserimento = risul_query($prenotazione_presente,$pren
 else $utente_inserimento = $id_utente;
 
 #if ($priv_vedi_tab_mesi == "p" and (($utente_inserimento != $id_utente and ($priv_prenota_gruppi != "SI" or !$utenti_gruppi[$utente_inserimento])) or ($periodo_consentito_app[$id_appartamento][$id_settimana] == "NO" and $esiste != 1))) {
-if ($priv_vedi_tab_mesi == "p" and (($utente_inserimento != $id_utente and ($priv_prenota_gruppi != "SI" or !$utenti_gruppi[$utente_inserimento])))) {
+if ($priv_vedi_tab_mesi == "p" and (($utente_inserimento != $id_utente and ($priv_prenota_gruppi != "SI" or empty($utenti_gruppi[$utente_inserimento]))))) {
 $freccia_sx = "";
 $freccia_dx = "";
-if ($utente_inserimento != $id_utente and ($priv_prenota_gruppi != "SI" or !$utenti_gruppi[$utente_inserimento])) {
+if ($utente_inserimento != $id_utente and ($priv_prenota_gruppi != "SI" or empty($utenti_gruppi[$utente_inserimento]))) {
 $id_inizio_prenota = risul_query($prenotazione_presente,$prenota_corr,'iddatainizio',$tableprenota);
 $id_fine_prenota = risul_query($prenotazione_presente,$prenota_corr,'iddatafine',$tableprenota);
 if ($id_inizio_prenota > $id_data_inizio_tab) $id_inizio = $id_inizio_prenota;
@@ -1095,7 +1111,7 @@ while ($fatto == "NO") {
 $id_inizio2 = $id_fine + 1;
 if ($id_inizio2 >= $ini_prenota_succ) {
 $utente_inserimento2 = risul_query($prenotazione_presente,$prenota_succ,'utente_inserimento',$tableprenota);
-if ($utente_inserimento2 != $id_utente and ($priv_prenota_gruppi != "SI" or !$utenti_gruppi[$utente_inserimento2])) {
+if ($utente_inserimento2 != $id_utente and ($priv_prenota_gruppi != "SI" or empty($utenti_gruppi[$utente_inserimento2]))) {
 $id_fine_prenota = risul_query($prenotazione_presente,$prenota_succ,'iddatafine',$tableprenota);
 if ($id_fine_prenota > $id_data_fine_tab) $freccia_dx = " -&gt;";
 if ($id_fine_prenota == $id_data_fine_tab) $controlla_pren_succ = 1;
@@ -1139,7 +1155,7 @@ if ($ut_ins_succ != $id_utente and ($priv_prenota_gruppi != "SI" or !$utenti_gru
 } # fine if ($controlla_pren_succ)
 if ($priv_oscura_tab_mesi != "v" and $priv_oscura_tab_mesi != "f") {
 $colonne_s = $colonne * 2;
-echo "<td style=\"background-color: #777777;\" colspan=\"$colonne_s\"><div style=\"visibility: hidden;\">$freccia_sx<a>&nbsp;</a>$freccia_dx</div></td>";
+echo "<td class=\"bcolclosed\" colspan=\"$colonne_s\"><div style=\"visibility: hidden;\">$freccia_sx<a>&nbsp;</a>$freccia_dx</div></td>";
 } # fine if ($priv_oscura_tab_mesi != "v" and $priv_oscura_tab_mesi != "f")
 if ($priv_oscura_tab_mesi == "v") {
 for ($num3 = 0 ; $num3 < $colonne ; $num3++) echo "<td colspan=\"2\">&nbsp;</td>";
@@ -1150,7 +1166,7 @@ if ($id_periodo_corrente > ($id_settimana + $num3)) echo "<td colspan=\"2\">&nbs
 else {
 if ($num3 > 0) $freccia_sx = "";
 $colonne_s = ($colonne - $num3) * 2;
-echo "<td style=\"background-color: #777777;\" colspan=\"$colonne_s\"><div style=\"visibility: hidden;\">$freccia_sx<a>&nbsp;</a>$freccia_dx</div></td>";
+echo "<td class=\"bcolclosed\" colspan=\"$colonne_s\"><div style=\"visibility: hidden;\">$freccia_sx<a>&nbsp;</a>$freccia_dx</div></td>";
 break;
 } # fine else if ($id_periodo_corrente > ($id_settimana + $num3))
 } # fine for $num3
@@ -1214,7 +1230,7 @@ if ($priv_mod_prenota_iniziate != "s" and $id_periodo_corrente >= $id_inizio_pre
 if ($priv_mod_prenota_ore != "000") {
 $adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
 $data_ins = risul_query($prenotazione_presente,$prenota_corr,'datainserimento',$tableprenota);
-$limite = date("YmdHis",mktime((substr($data_ins,11,2) + $priv_mod_prenota_ore),substr($data_ins,14,2),substr($data_ins,17,2),substr($data_ins,5,2),substr($data_ins,8,2),substr($data_ins,0,4)));
+$limite = date("YmdHis",mktime((substr($data_ins,11,2) + (int) $priv_mod_prenota_ore),substr($data_ins,14,2),substr($data_ins,17,2),substr($data_ins,5,2),substr($data_ins,8,2),substr($data_ins,0,4)));
 if ($adesso > $limite) $link_modifica = "NO";
 } # fine if ($priv_mod_prenota_ore != "000")
 if ($link_modifica == "SI" and $id_clienti) {
@@ -1273,7 +1289,7 @@ echo "</td><td></td></tr></table></td>";
 $num2 = $num2 + $colonne - 1;
 } # fine if ($esiste == 1)
 else {
-if (isset($reg1_chiuso) and isset($reg1_chiuso[$id_appartamento][$id_settimana])) echo "<td style=\"background-color: #777777;\" colspan=\"2\">&nbsp;</td>";
+if (isset($reg1_chiuso[$id_appartamento][$id_settimana])) echo "<td class=\"bcolclosed\" colspan=\"2\">&nbsp;</td>";
 else echo "<td colspan=\"2\">&nbsp;</td>";
 } # fine else if ($esiste == 1)
 
